# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BatchArchiveContextLabelsInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'context_label_ids': 'list[str]',
        'table_id': 'str'
    }

    attribute_map = {
        'context_label_ids': 'contextLabelIds',
        'table_id': 'tableId'
    }

    def __init__(self, context_label_ids=None, table_id=None):
        """
        BatchArchiveContextLabelsInputV1 - a model defined in Swagger
        """

        self._context_label_ids = None
        self._table_id = None

        if context_label_ids is not None:
          self.context_label_ids = context_label_ids
        if table_id is not None:
          self.table_id = table_id

    @property
    def context_label_ids(self):
        """
        Gets the context_label_ids of this BatchArchiveContextLabelsInputV1.
        List of context label IDs to archive

        :return: The context_label_ids of this BatchArchiveContextLabelsInputV1.
        :rtype: list[str]
        """
        return self._context_label_ids

    @context_label_ids.setter
    def context_label_ids(self, context_label_ids):
        """
        Sets the context_label_ids of this BatchArchiveContextLabelsInputV1.
        List of context label IDs to archive

        :param context_label_ids: The context_label_ids of this BatchArchiveContextLabelsInputV1.
        :type: list[str]
        """

        self._context_label_ids = context_label_ids

    @property
    def table_id(self):
        """
        Gets the table_id of this BatchArchiveContextLabelsInputV1.
        If provided, the ID of the Table Definition that will be used for permissions checking. The user needs read permissions on the provided table definition and theitem has to be in the table in order to create, update, or delete context. If not provided, the user must have read permissions on the item id the context is being applied to.

        :return: The table_id of this BatchArchiveContextLabelsInputV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this BatchArchiveContextLabelsInputV1.
        If provided, the ID of the Table Definition that will be used for permissions checking. The user needs read permissions on the provided table definition and theitem has to be in the table in order to create, update, or delete context. If not provided, the user must have read permissions on the item id the context is being applied to.

        :param table_id: The table_id of this BatchArchiveContextLabelsInputV1.
        :type: str
        """

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BatchArchiveContextLabelsInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
