# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class DatasourcesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_datasource(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clean_up(
        self,
        **kwargs: Any,
    ) -> DatasourceCleanUpOutputV1: ...

    def clean_up_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clear_datasource_cache(
        self,
        **kwargs: Any,
    ) -> DatasourceCacheClearOutputV1: ...

    def clear_datasource_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_datasource(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputV1: ...

    def create_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def disable_connections(
        self,
        **kwargs: Any,
    ) -> ConnectionsOutputV1: ...

    def disable_connections_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def fully_archive_datasource(
        self,
        **kwargs: Any,
    ) -> JobAcceptedOutputV1: ...

    def fully_archive_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_datasource(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputV1: ...

    def get_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_datasources(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputListV1: ...

    def get_datasources_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_items_hosted_by_datasource(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_items_hosted_by_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_precached_items(
        self,
        **kwargs: Any,
    ) -> PrecachedItemsOutputV1: ...

    def get_precached_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_status(
        self,
        **kwargs: Any,
    ) -> DatasourceStatusOutputV1: ...

    def get_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def recount(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputV1: ...

    def recount_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
