# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _applied_filter: Optional[str]
    _archived: Optional[bool]
    _background_color: Optional[str]
    _columns: int
    _created_at: Optional[str]
    _description: Optional[str]
    _enabled: Optional[bool]
    _end_date: Optional[str]
    _filters: List[BoardFilterOutputV1]
    _id: str
    _locked: Optional[bool]
    _name: str
    _row_height: int
    _scoped_to: Optional[str]
    _start_date: Optional[str]
    _tiles: List[TileOutputV1]
    _timezone: str
    _updated_at: Optional[str]


    def __init__(
        self,
        applied_filter: Optional[str] = None,
        archived: Optional[bool] = None,
        background_color: Optional[str] = None,
        columns: Optional[int] = None,
        created_at: Optional[str] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = None,
        end_date: Optional[str] = None,
        filters: Optional[List[BoardFilterOutputV1]] = None,
        id: Optional[str] = None,
        locked: Optional[bool] = None,
        name: Optional[str] = None,
        row_height: Optional[int] = None,
        scoped_to: Optional[str] = None,
        start_date: Optional[str] = None,
        tiles: Optional[List[TileOutputV1]] = None,
        timezone: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def applied_filter(self) -> Optional[str]: ...

    @applied_filter.setter
    def applied_filter(self, applied_filter: Optional[str]) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def background_color(self) -> Optional[str]: ...

    @background_color.setter
    def background_color(self, background_color: Optional[str]) -> None: ...

    @property
    def columns(self) -> int: ...

    @columns.setter
    def columns(self, columns: int) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def end_date(self) -> Optional[str]: ...

    @end_date.setter
    def end_date(self, end_date: Optional[str]) -> None: ...

    @property
    def filters(self) -> List[BoardFilterOutputV1]: ...

    @filters.setter
    def filters(self, filters: List[BoardFilterOutputV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def locked(self) -> Optional[bool]: ...

    @locked.setter
    def locked(self, locked: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def row_height(self) -> int: ...

    @row_height.setter
    def row_height(self, row_height: int) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def start_date(self) -> Optional[str]: ...

    @start_date.setter
    def start_date(self, start_date: Optional[str]) -> None: ...

    @property
    def tiles(self) -> List[TileOutputV1]: ...

    @tiles.setter
    def tiles(self, tiles: List[TileOutputV1]) -> None: ...

    @property
    def timezone(self) -> str: ...

    @timezone.setter
    def timezone(self, timezone: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
