# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ItemsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_access_control_entry(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def add_access_control_entry_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_item(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_item_finder(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def change_owner(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def change_owner_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clear_cache(
        self,
        **kwargs: Any,
    ) -> CacheInfoV1: ...

    def clear_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def create_context_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def create_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_property(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_property_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def execute_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def execute_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def execute_item_finder_searches(
        self,
        **kwargs: Any,
    ) -> ItemFinderSearchesOutputV1: ...

    def execute_item_finder_searches_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def find_swap(
        self,
        **kwargs: Any,
    ) -> ItemPreviewV1: ...

    def find_swap_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_access_control(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def get_access_control_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_access_control_details(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def get_access_control_details_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def get_context_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_dependencies(
        self,
        **kwargs: Any,
    ) -> ItemDependencyOutputV1: ...

    def get_formula_dependencies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_dependents(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_formula_dependents_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_interested(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_interested_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_and_all_properties(
        self,
        **kwargs: Any,
    ) -> ItemOutputV1: ...

    def get_item_and_all_properties_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def get_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_finders(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputListV1: ...

    def get_item_finders_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_preview(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewV1: ...

    def get_item_preview_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_usages(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_item_usages_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_user_attributes(
        self,
        **kwargs: Any,
    ) -> ItemUserAttributesOutputV1: ...

    def get_item_user_attributes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_parent_datasources(
        self,
        **kwargs: Any,
    ) -> DatasourcePairsOutputV1: ...

    def get_parent_datasources_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_pinned_items(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def get_pinned_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_property(
        self,
        **kwargs: Any,
    ) -> PropertyOutputV1: ...

    def get_property_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_stored_table_search_failures(
        self,
        **kwargs: Any,
    ) -> StoredTableSearchFailureOutputListV1: ...

    def get_stored_table_search_failures_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_swap_options(
        self,
        **kwargs: Any,
    ) -> SwapOptionListV1: ...

    def get_swap_options_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def lock_item(
        self,
        **kwargs: Any,
    ) -> LockedItemListOutputV1: ...

    def lock_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def pin_item(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def pin_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_access_control_entry(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def remove_access_control_entry_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reset_cdc(
        self,
        **kwargs: Any,
    ) -> PropertyOutputV1: ...

    def reset_cdc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search_items(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewPaginatedListV1: ...

    def search_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search_items_post(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewPaginatedListV1: ...

    def search_items_post_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_acl(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def set_acl_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_acl_inheritance(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def set_acl_inheritance_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_formula(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def set_formula_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_item_user_attributes(
        self,
        **kwargs: Any,
    ) -> ItemUserAttributesOutputV1: ...

    def set_item_user_attributes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_properties(
        self,
        **kwargs: Any,
    ) -> ItemOutputV1: ...

    def set_properties_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_property(
        self,
        **kwargs: Any,
    ) -> PropertyHrefOutputV1: ...

    def set_property_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_scope(
        self,
        **kwargs: Any,
    ) -> ItemOutputV1: ...

    def set_scope_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unpin_item(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def unpin_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def update_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_item_lockability(
        self,
        **kwargs: Any,
    ) -> LockErrorsOutputV1: ...

    def validate_item_lockability_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
