# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ProjectsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_schedule_notebook_result(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookOutputV1: ...

    def add_schedule_notebook_result_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_project(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_project(
        self,
        **kwargs: Any,
    ) -> ProjectOutputV1: ...

    def create_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_project(
        self,
        **kwargs: Any,
    ) -> ProjectOutputV1: ...

    def get_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_projects(
        self,
        **kwargs: Any,
    ) -> GetProjectsOutputV1: ...

    def get_projects_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_scheduled_notebook(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookOutputV1: ...

    def get_scheduled_notebook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_scheduled_notebooks(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookListOutputV1: ...

    def get_scheduled_notebooks_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_project(
        self,
        **kwargs: Any,
    ) -> ProjectOutputV1: ...

    def put_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def schedule_notebook(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookOutputV1: ...

    def schedule_notebook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unschedule_notebook(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookListOutputV1: ...

    def unschedule_notebook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
