# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AuditOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _affected_items: List[str]
    _after_summary: str
    _before_summary: str
    _change_type: str
    _item_id: str
    _item_name: str
    _item_type: str
    _time_stamp: str
    _user_id: str
    _user_name: str


    def __init__(
        self,
        affected_items: Optional[List[str]] = None,
        after_summary: Optional[str] = None,
        before_summary: Optional[str] = None,
        change_type: Optional[str] = None,
        item_id: Optional[str] = None,
        item_name: Optional[str] = None,
        item_type: Optional[str] = None,
        time_stamp: Optional[str] = None,
        user_id: Optional[str] = None,
        user_name: Optional[str] = None,
    ) -> None: ...

    @property
    def affected_items(self) -> List[str]: ...

    @affected_items.setter
    def affected_items(self, affected_items: List[str]) -> None: ...

    @property
    def after_summary(self) -> str: ...

    @after_summary.setter
    def after_summary(self, after_summary: str) -> None: ...

    @property
    def before_summary(self) -> str: ...

    @before_summary.setter
    def before_summary(self, before_summary: str) -> None: ...

    @property
    def change_type(self) -> str: ...

    @change_type.setter
    def change_type(self, change_type: str) -> None: ...

    @property
    def item_id(self) -> str: ...

    @item_id.setter
    def item_id(self, item_id: str) -> None: ...

    @property
    def item_name(self) -> str: ...

    @item_name.setter
    def item_name(self, item_name: str) -> None: ...

    @property
    def item_type(self) -> str: ...

    @item_type.setter
    def item_type(self, item_type: str) -> None: ...

    @property
    def time_stamp(self) -> str: ...

    @time_stamp.setter
    def time_stamp(self, time_stamp: str) -> None: ...

    @property
    def user_id(self) -> str: ...

    @user_id.setter
    def user_id(self, user_id: str) -> None: ...

    @property
    def user_name(self) -> str: ...

    @user_name.setter
    def user_name(self, user_name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
