# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTileGetInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applied_filters': 'list[BoardFilterInputV1]',
        'end_date': 'str',
        'start_date': 'str'
    }

    attribute_map = {
        'applied_filters': 'appliedFilters',
        'end_date': 'endDate',
        'start_date': 'startDate'
    }

    def __init__(self, applied_filters=None, end_date=None, start_date=None):
        """
        BoardTileGetInputV1 - a model defined in Swagger
        """

        self._applied_filters = None
        self._end_date = None
        self._start_date = None

        if applied_filters is not None:
          self.applied_filters = applied_filters
        if end_date is not None:
          self.end_date = end_date
        if start_date is not None:
          self.start_date = start_date

    @property
    def applied_filters(self):
        """
        Gets the applied_filters of this BoardTileGetInputV1.
        Filters to apply to the board and tile data

        :return: The applied_filters of this BoardTileGetInputV1.
        :rtype: list[BoardFilterInputV1]
        """
        return self._applied_filters

    @applied_filters.setter
    def applied_filters(self, applied_filters):
        """
        Sets the applied_filters of this BoardTileGetInputV1.
        Filters to apply to the board and tile data

        :param applied_filters: The applied_filters of this BoardTileGetInputV1.
        :type: list[BoardFilterInputV1]
        """

        self._applied_filters = applied_filters

    @property
    def end_date(self):
        """
        Gets the end_date of this BoardTileGetInputV1.
        The end date for the date range of the data

        :return: The end_date of this BoardTileGetInputV1.
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BoardTileGetInputV1.
        The end date for the date range of the data

        :param end_date: The end_date of this BoardTileGetInputV1.
        :type: str
        """

        self._end_date = end_date

    @property
    def start_date(self):
        """
        Gets the start_date of this BoardTileGetInputV1.
        The start date for the date range of the data

        :return: The start_date of this BoardTileGetInputV1.
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BoardTileGetInputV1.
        The start date for the date range of the data

        :param start_date: The start_date of this BoardTileGetInputV1.
        :type: str
        """

        self._start_date = start_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTileGetInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
