# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CalculatedTableOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _archived: Optional[bool]
    _column_dependencies: Optional[List[CalculatedTableColumnDependencyOutputV1]]
    _column_metadata: Optional[List[CalculatedTableColumnMetadataOutputV1]]
    _created_at: Optional[str]
    _creator_id: Optional[str]
    _description: Optional[str]
    _id: Optional[str]
    _locked: Optional[bool]
    _name: Optional[str]
    _owner_id: Optional[str]
    _query: Optional[str]
    _scoped_to: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        archived: Optional[bool] = None,
        column_dependencies: Optional[List[CalculatedTableColumnDependencyOutputV1]] = None,
        column_metadata: Optional[List[CalculatedTableColumnMetadataOutputV1]] = None,
        created_at: Optional[str] = None,
        creator_id: Optional[str] = None,
        description: Optional[str] = None,
        id: Optional[str] = None,
        locked: Optional[bool] = None,
        name: Optional[str] = None,
        owner_id: Optional[str] = None,
        query: Optional[str] = None,
        scoped_to: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def column_dependencies(self) -> Optional[List[CalculatedTableColumnDependencyOutputV1]]: ...

    @column_dependencies.setter
    def column_dependencies(self, column_dependencies: Optional[List[CalculatedTableColumnDependencyOutputV1]]) -> None: ...

    @property
    def column_metadata(self) -> Optional[List[CalculatedTableColumnMetadataOutputV1]]: ...

    @column_metadata.setter
    def column_metadata(self, column_metadata: Optional[List[CalculatedTableColumnMetadataOutputV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator_id(self) -> Optional[str]: ...

    @creator_id.setter
    def creator_id(self, creator_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def locked(self) -> Optional[bool]: ...

    @locked.setter
    def locked(self, locked: Optional[bool]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def owner_id(self) -> Optional[str]: ...

    @owner_id.setter
    def owner_id(self, owner_id: Optional[str]) -> None: ...

    @property
    def query(self) -> Optional[str]: ...

    @query.setter
    def query(self, query: Optional[str]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
