# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SentEmailOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _attachments: List[SentEmailAttachmentOutputV1]
    _bcc_emails: List[str]
    _cc_emails: List[str]
    _content: str
    _id: str
    _response_code: int
    _response_message: Optional[str]
    _sender: Optional[ItemPreviewV1]
    _sent_at: str
    _source: Optional[ItemPreviewV1]
    _subject: str
    _to_emails: List[str]


    def __init__(
        self,
        attachments: Optional[List[SentEmailAttachmentOutputV1]] = None,
        bcc_emails: Optional[List[str]] = None,
        cc_emails: Optional[List[str]] = None,
        content: Optional[str] = None,
        id: Optional[str] = None,
        response_code: Optional[int] = None,
        response_message: Optional[str] = None,
        sender: Optional[ItemPreviewV1] = None,
        sent_at: Optional[str] = None,
        source: Optional[ItemPreviewV1] = None,
        subject: Optional[str] = None,
        to_emails: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def attachments(self) -> List[SentEmailAttachmentOutputV1]: ...

    @attachments.setter
    def attachments(self, attachments: List[SentEmailAttachmentOutputV1]) -> None: ...

    @property
    def bcc_emails(self) -> List[str]: ...

    @bcc_emails.setter
    def bcc_emails(self, bcc_emails: List[str]) -> None: ...

    @property
    def cc_emails(self) -> List[str]: ...

    @cc_emails.setter
    def cc_emails(self, cc_emails: List[str]) -> None: ...

    @property
    def content(self) -> str: ...

    @content.setter
    def content(self, content: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def response_code(self) -> int: ...

    @response_code.setter
    def response_code(self, response_code: int) -> None: ...

    @property
    def response_message(self) -> Optional[str]: ...

    @response_message.setter
    def response_message(self, response_message: Optional[str]) -> None: ...

    @property
    def sender(self) -> Optional[ItemPreviewV1]: ...

    @sender.setter
    def sender(self, sender: Optional[ItemPreviewV1]) -> None: ...

    @property
    def sent_at(self) -> str: ...

    @sent_at.setter
    def sent_at(self, sent_at: str) -> None: ...

    @property
    def source(self) -> Optional[ItemPreviewV1]: ...

    @source.setter
    def source(self, source: Optional[ItemPreviewV1]) -> None: ...

    @property
    def subject(self) -> str: ...

    @subject.setter
    def subject(self, subject: str) -> None: ...

    @property
    def to_emails(self) -> List[str]: ...

    @to_emails.setter
    def to_emails(self, to_emails: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
