# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AnnotationInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _backup_name: Optional[str]
    _created_by_id: Optional[str]
    _description: Optional[str]
    _discoverable: Optional[bool]
    _document: Optional[str]
    _interests: Optional[List[AnnotationInterestInputV1]]
    _name: str
    _replies_to: Optional[str]
    _report_input: Optional[OptionalReportInputV1]
    _type: Optional[str]


    def __init__(
        self,
        backup_name: Optional[str] = None,
        created_by_id: Optional[str] = None,
        description: Optional[str] = None,
        discoverable: Optional[bool] = None,
        document: Optional[str] = None,
        interests: Optional[List[AnnotationInterestInputV1]] = None,
        name: Optional[str] = None,
        replies_to: Optional[str] = None,
        report_input: Optional[OptionalReportInputV1] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def backup_name(self) -> Optional[str]: ...

    @backup_name.setter
    def backup_name(self, backup_name: Optional[str]) -> None: ...

    @property
    def created_by_id(self) -> Optional[str]: ...

    @created_by_id.setter
    def created_by_id(self, created_by_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def discoverable(self) -> Optional[bool]: ...

    @discoverable.setter
    def discoverable(self, discoverable: Optional[bool]) -> None: ...

    @property
    def document(self) -> Optional[str]: ...

    @document.setter
    def document(self, document: Optional[str]) -> None: ...

    @property
    def interests(self) -> Optional[List[AnnotationInterestInputV1]]: ...

    @interests.setter
    def interests(self, interests: Optional[List[AnnotationInterestInputV1]]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def replies_to(self) -> Optional[str]: ...

    @replies_to.setter
    def replies_to(self, replies_to: Optional[str]) -> None: ...

    @property
    def report_input(self) -> Optional[OptionalReportInputV1]: ...

    @report_input.setter
    def report_input(self, report_input: Optional[OptionalReportInputV1]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
