# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentRevisionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'created_by': 'str',
        'created_by_id': 'str',
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'created_by': 'createdBy',
        'created_by_id': 'createdById',
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, created_by=None, created_by_id=None, id=None, name=None, type=None, updated_at=None):
        """
        CustomAgentRevisionOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._created_by = None
        self._created_by_id = None
        self._id = None
        self._name = None
        self._type = None
        self._updated_at = None

        if created_at is not None:
          self.created_at = created_at
        if created_by is not None:
          self.created_by = created_by
        if created_by_id is not None:
          self.created_by_id = created_by_id
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if type is not None:
          self.type = type
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def created_at(self):
        """
        Gets the created_at of this CustomAgentRevisionOutputV1.
        The time the workflow revision was created

        :return: The created_at of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this CustomAgentRevisionOutputV1.
        The time the workflow revision was created

        :param created_at: The created_at of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def created_by(self):
        """
        Gets the created_by of this CustomAgentRevisionOutputV1.
        The username of the workflow revision creator (if available)

        :return: The created_by of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this CustomAgentRevisionOutputV1.
        The username of the workflow revision creator (if available)

        :param created_by: The created_by of this CustomAgentRevisionOutputV1.
        :type: str
        """

        self._created_by = created_by

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this CustomAgentRevisionOutputV1.
        The item ID of the workflow revision creator (if available)

        :return: The created_by_id of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this CustomAgentRevisionOutputV1.
        The item ID of the workflow revision creator (if available)

        :param created_by_id: The created_by_id of this CustomAgentRevisionOutputV1.
        :type: str
        """

        self._created_by_id = created_by_id

    @property
    def id(self):
        """
        Gets the id of this CustomAgentRevisionOutputV1.
        The workflow revision item ID

        :return: The id of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CustomAgentRevisionOutputV1.
        The workflow revision item ID

        :param id: The id of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CustomAgentRevisionOutputV1.
        The workflow revision item name

        :return: The name of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CustomAgentRevisionOutputV1.
        The workflow revision item name

        :param name: The name of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this CustomAgentRevisionOutputV1.
        The workflow revision item type

        :return: The type of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CustomAgentRevisionOutputV1.
        The workflow revision item type

        :param type: The type of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def updated_at(self):
        """
        Gets the updated_at of this CustomAgentRevisionOutputV1.
        The last time the workflow revision was updated

        :return: The updated_at of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this CustomAgentRevisionOutputV1.
        The last time the workflow revision was updated

        :param updated_at: The updated_at of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if updated_at is None:
            raise ValueError("Invalid value for `updated_at`, must not be `None`")

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentRevisionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
