# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class WorkbooksApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_recently_accessed(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def add_recently_accessed_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_workbook(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_workbook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_worksheet(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_sandbox(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def create_sandbox_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_workbook(
        self,
        **kwargs: Any,
    ) -> WorkbookOutputV1: ...

    def create_workbook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_worksheet(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def create_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_worksheet_thumbnail(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def create_worksheet_thumbnail_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_workstep(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def create_workstep_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_recently_accessed(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def get_recently_accessed_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_referenced_items(
        self,
        **kwargs: Any,
    ) -> ReferencedItemsOutputV1: ...

    def get_referenced_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workbook(
        self,
        **kwargs: Any,
    ) -> WorkbookOutputV1: ...

    def get_workbook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workbook_owner(
        self,
        **kwargs: Any,
    ) -> WorkbookOwnerOutputV1: ...

    def get_workbook_owner_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workbooks(
        self,
        **kwargs: Any,
    ) -> WorkbookOutputListV1: ...

    def get_workbooks_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheet(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def get_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheet_thumbnail(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_worksheet_thumbnail_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheet_usages(
        self,
        **kwargs: Any,
    ) -> AnnotationListOutputV1: ...

    def get_worksheet_usages_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheets(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputListV1: ...

    def get_worksheets_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workstep(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def get_workstep_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workstep_by_id(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def get_workstep_by_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksteps(
        self,
        **kwargs: Any,
    ) -> WorkstepChronologyOutputV1: ...

    def get_worksteps_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_worksheet(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def move_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_current_workstep(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def set_current_workstep_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_renderer(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def set_renderer_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
