# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class UsersApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def autocomplete_users_and_groups(
        self,
        **kwargs: Any,
    ) -> IdentityPreviewListV1: ...

    def autocomplete_users_and_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_user(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def create_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_user(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_items_shared_with_identity(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_items_shared_with_identity_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_items_shared_with_me(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_items_shared_with_me_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_me(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def get_me_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def get_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user_from_username(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def get_user_from_username_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_users(
        self,
        **kwargs: Any,
    ) -> UserOutputListV1: ...

    def get_users_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_trust(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def set_trust_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_password(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def update_password_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_user(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def update_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
