# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, Optional


class ClientConfiguration(object):
    DEFAULT_RETRY_TIMEOUT_IN_SECONDS: int
    DEFAULT_REQUEST_TIMEOUT_IN_SECONDS: Optional[int]

    host: str
    api_client: Any

    api_key: Dict[str, str]
    api_key_prefix: Dict[str, str]
    username: str
    password: str

    verify_ssl: bool
    ssl_ca_cert: Optional[str]
    cert_file: Optional[str]
    key_file: Optional[str]
    assert_hostname: Any

    proxy: Optional[str]

    retry_timeout_in_seconds: int
    request_timeout_in_seconds: Optional[int]

    client_side_validation: bool

    @staticmethod
    def get_default_instance() -> ClientConfiguration: ...

    def __init__(self) -> None: ...

    def get_api_key_with_prefix(self, identifier: str) -> Optional[str]: ...
    def get_basic_auth_token(self) -> str: ...

    def set_default(self, default: Optional[ClientConfiguration] = None) -> None: ...

    def set_identity_path(self, identity_path: str) -> None: ...
    def set_csrf_token(self, csrf_token: str) -> None: ...
    def set_auth_token(self, auth_token: str) -> None: ...
    def set_api_key(self, api_key: str) -> None: ...

    def set_ssl_ca_cert_from_cert_list_file(self, cert_file_path: str) -> None: ...

    def auth_settings(self) -> Dict[str, Dict[str, Any]]: ...

    def to_debug_report(self) -> str: ...


default_configuration: ClientConfiguration


def Configuration() -> ClientConfiguration: ...
