# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SupportRequestInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _attachment: Optional[AttachmentInputV1]
    _attachment_for_jira: Optional[JiraAttachment]
    _description: str
    _email: str
    _frequency: str
    _name: str
    _severity: str
    _steps_to_reproduce: Optional[str]
    _summary: str


    def __init__(
        self,
        attachment: Optional[AttachmentInputV1] = None,
        attachment_for_jira: Optional[JiraAttachment] = None,
        description: Optional[str] = None,
        email: Optional[str] = None,
        frequency: Optional[str] = None,
        name: Optional[str] = None,
        severity: Optional[str] = None,
        steps_to_reproduce: Optional[str] = None,
        summary: Optional[str] = None,
    ) -> None: ...

    @property
    def attachment(self) -> Optional[AttachmentInputV1]: ...

    @attachment.setter
    def attachment(self, attachment: Optional[AttachmentInputV1]) -> None: ...

    @property
    def attachment_for_jira(self) -> Optional[JiraAttachment]: ...

    @attachment_for_jira.setter
    def attachment_for_jira(self, attachment_for_jira: Optional[JiraAttachment]) -> None: ...

    @property
    def description(self) -> str: ...

    @description.setter
    def description(self, description: str) -> None: ...

    @property
    def email(self) -> str: ...

    @email.setter
    def email(self, email: str) -> None: ...

    @property
    def frequency(self) -> str: ...

    @frequency.setter
    def frequency(self, frequency: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def severity(self) -> str: ...

    @severity.setter
    def severity(self, severity: str) -> None: ...

    @property
    def steps_to_reproduce(self) -> Optional[str]: ...

    @steps_to_reproduce.setter
    def steps_to_reproduce(self, steps_to_reproduce: Optional[str]) -> None: ...

    @property
    def summary(self) -> str: ...

    @summary.setter
    def summary(self, summary: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
