# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaPackageImportInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _docs: List[FormulaDocInputV1]
    _formula_package: FormulaPackageInputV1
    _functions: List[FunctionInputV1]
    _sync_token: Optional[str]


    def __init__(
        self,
        docs: Optional[List[FormulaDocInputV1]] = None,
        formula_package: Optional[FormulaPackageInputV1] = None,
        functions: Optional[List[FunctionInputV1]] = None,
        sync_token: Optional[str] = None,
    ) -> None: ...

    @property
    def docs(self) -> List[FormulaDocInputV1]: ...

    @docs.setter
    def docs(self, docs: List[FormulaDocInputV1]) -> None: ...

    @property
    def formula_package(self) -> FormulaPackageInputV1: ...

    @formula_package.setter
    def formula_package(self, formula_package: FormulaPackageInputV1) -> None: ...

    @property
    def functions(self) -> List[FunctionInputV1]: ...

    @functions.setter
    def functions(self, functions: List[FunctionInputV1]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
