# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelTableApplicationsOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _id: Optional[str]
    _mappings: Optional[List[ModelApplicationMappingV1]]
    _model_container_id: Optional[str]
    _model_guid: Optional[str]
    _model_name: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        id: Optional[str] = None,
        mappings: Optional[List[ModelApplicationMappingV1]] = None,
        model_container_id: Optional[str] = None,
        model_guid: Optional[str] = None,
        model_name: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def mappings(self) -> Optional[List[ModelApplicationMappingV1]]: ...

    @mappings.setter
    def mappings(self, mappings: Optional[List[ModelApplicationMappingV1]]) -> None: ...

    @property
    def model_container_id(self) -> Optional[str]: ...

    @model_container_id.setter
    def model_container_id(self, model_container_id: Optional[str]) -> None: ...

    @property
    def model_guid(self) -> Optional[str]: ...

    @model_guid.setter
    def model_guid(self, model_guid: Optional[str]) -> None: ...

    @property
    def model_name(self) -> Optional[str]: ...

    @model_name.setter
    def model_name(self, model_name: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
