# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class FoldersApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_folder(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def create_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_ancestors(
        self,
        **kwargs: Any,
    ) -> FolderNavigationOutputV1: ...

    def get_ancestors_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def get_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_folders(
        self,
        **kwargs: Any,
    ) -> WorkbenchItemOutputListV1: ...

    def get_folders_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_pinned(
        self,
        **kwargs: Any,
    ) -> FolderSearchResultsV1: ...

    def get_pinned_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_recently_used(
        self,
        **kwargs: Any,
    ) -> FolderSearchResultsV1: ...

    def get_recently_used_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_subfolders(
        self,
        **kwargs: Any,
    ) -> FolderNavigationOutputV1: ...

    def get_subfolders_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_item_to_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def move_item_to_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_item_from_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def remove_item_from_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search(
        self,
        **kwargs: Any,
    ) -> FolderSearchResultsV1: ...

    def search_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
