# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LabelHierarchyInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _depth: Optional[int]
    _include_archived: Optional[bool]
    _max_nodes: Optional[int]
    _pairs: Optional[List[CategoryLabelPairInputV1]]


    def __init__(
        self,
        depth: Optional[int] = 10,
        include_archived: Optional[bool] = False,
        max_nodes: Optional[int] = 1000,
        pairs: Optional[List[CategoryLabelPairInputV1]] = None,
    ) -> None: ...

    @property
    def depth(self) -> Optional[int]: ...

    @depth.setter
    def depth(self, depth: Optional[int]) -> None: ...

    @property
    def include_archived(self) -> Optional[bool]: ...

    @include_archived.setter
    def include_archived(self, include_archived: Optional[bool]) -> None: ...

    @property
    def max_nodes(self) -> Optional[int]: ...

    @max_nodes.setter
    def max_nodes(self, max_nodes: Optional[int]) -> None: ...

    @property
    def pairs(self) -> Optional[List[CategoryLabelPairInputV1]]: ...

    @pairs.setter
    def pairs(self, pairs: Optional[List[CategoryLabelPairInputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
