# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserGroupOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _capabilities: Optional[List[CapabilityInheritanceOutputV1]]
    _capability_grants: Optional[List[CapabilityInheritanceOutputV1]]
    _created_at: Optional[str]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _datasource_name: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _id: str
    _is_archived: Optional[bool]
    _is_enabled: Optional[bool]
    _is_organization_group: Optional[bool]
    _is_redacted: Optional[bool]
    _is_remote_group_editable: Optional[bool]
    _is_used_in_access_control_entries: Optional[bool]
    _members: Optional[List[IdentityPreviewV1]]
    _name: str
    _status_message: Optional[str]
    _sync_token: Optional[str]
    _translation_key: Optional[str]
    _type: str


    def __init__(
        self,
        capabilities: Optional[List[CapabilityInheritanceOutputV1]] = None,
        capability_grants: Optional[List[CapabilityInheritanceOutputV1]] = None,
        created_at: Optional[str] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        datasource_name: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_enabled: Optional[bool] = False,
        is_organization_group: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        is_remote_group_editable: Optional[bool] = False,
        is_used_in_access_control_entries: Optional[bool] = False,
        members: Optional[List[IdentityPreviewV1]] = None,
        name: Optional[str] = None,
        status_message: Optional[str] = None,
        sync_token: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def capabilities(self) -> Optional[List[CapabilityInheritanceOutputV1]]: ...

    @capabilities.setter
    def capabilities(self, capabilities: Optional[List[CapabilityInheritanceOutputV1]]) -> None: ...

    @property
    def capability_grants(self) -> Optional[List[CapabilityInheritanceOutputV1]]: ...

    @capability_grants.setter
    def capability_grants(self, capability_grants: Optional[List[CapabilityInheritanceOutputV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def datasource_name(self) -> Optional[str]: ...

    @datasource_name.setter
    def datasource_name(self, datasource_name: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def is_organization_group(self) -> Optional[bool]: ...

    @is_organization_group.setter
    def is_organization_group(self, is_organization_group: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def is_remote_group_editable(self) -> Optional[bool]: ...

    @is_remote_group_editable.setter
    def is_remote_group_editable(self, is_remote_group_editable: Optional[bool]) -> None: ...

    @property
    def is_used_in_access_control_entries(self) -> Optional[bool]: ...

    @is_used_in_access_control_entries.setter
    def is_used_in_access_control_entries(self, is_used_in_access_control_entries: Optional[bool]) -> None: ...

    @property
    def members(self) -> Optional[List[IdentityPreviewV1]]: ...

    @members.setter
    def members(self, members: Optional[List[IdentityPreviewV1]]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
