# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _access_key_validity_duration: Optional[int]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _email: str
    _first_name: str
    _is_admin: Optional[bool]
    _is_enabled: Optional[bool]
    _last_name: str
    _manager: Optional[str]
    _max_requests: Optional[int]
    _name: Optional[str]
    _password: Optional[str]
    _require_password_reset_on_next_login: Optional[bool]
    _role: Optional[str]
    _session_duration: Optional[int]
    _site: Optional[str]
    _template_workstep_id: Optional[str]
    _username: str
    _workbench: Optional[str]


    def __init__(
        self,
        access_key_validity_duration: Optional[int] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        email: Optional[str] = None,
        first_name: Optional[str] = None,
        is_admin: Optional[bool] = None,
        is_enabled: Optional[bool] = None,
        last_name: Optional[str] = None,
        manager: Optional[str] = None,
        max_requests: Optional[int] = None,
        name: Optional[str] = None,
        password: Optional[str] = None,
        require_password_reset_on_next_login: Optional[bool] = None,
        role: Optional[str] = None,
        session_duration: Optional[int] = None,
        site: Optional[str] = None,
        template_workstep_id: Optional[str] = None,
        username: Optional[str] = None,
        workbench: Optional[str] = None,
    ) -> None: ...

    @property
    def access_key_validity_duration(self) -> Optional[int]: ...

    @access_key_validity_duration.setter
    def access_key_validity_duration(self, access_key_validity_duration: Optional[int]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def email(self) -> str: ...

    @email.setter
    def email(self, email: str) -> None: ...

    @property
    def first_name(self) -> str: ...

    @first_name.setter
    def first_name(self, first_name: str) -> None: ...

    @property
    def is_admin(self) -> Optional[bool]: ...

    @is_admin.setter
    def is_admin(self, is_admin: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def last_name(self) -> str: ...

    @last_name.setter
    def last_name(self, last_name: str) -> None: ...

    @property
    def manager(self) -> Optional[str]: ...

    @manager.setter
    def manager(self, manager: Optional[str]) -> None: ...

    @property
    def max_requests(self) -> Optional[int]: ...

    @max_requests.setter
    def max_requests(self, max_requests: Optional[int]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def password(self) -> Optional[str]: ...

    @password.setter
    def password(self, password: Optional[str]) -> None: ...

    @property
    def require_password_reset_on_next_login(self) -> Optional[bool]: ...

    @require_password_reset_on_next_login.setter
    def require_password_reset_on_next_login(self, require_password_reset_on_next_login: Optional[bool]) -> None: ...

    @property
    def role(self) -> Optional[str]: ...

    @role.setter
    def role(self, role: Optional[str]) -> None: ...

    @property
    def session_duration(self) -> Optional[int]: ...

    @session_duration.setter
    def session_duration(self, session_duration: Optional[int]) -> None: ...

    @property
    def site(self) -> Optional[str]: ...

    @site.setter
    def site(self, site: Optional[str]) -> None: ...

    @property
    def template_workstep_id(self) -> Optional[str]: ...

    @template_workstep_id.setter
    def template_workstep_id(self, template_workstep_id: Optional[str]) -> None: ...

    @property
    def username(self) -> str: ...

    @username.setter
    def username(self, username: str) -> None: ...

    @property
    def workbench(self) -> Optional[str]: ...

    @workbench.setter
    def workbench(self, workbench: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
