# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class NotificationConfigurationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bcc_email_recipients: List[EmailNotificationRecipientOutputV1]
    _capsule_grouping: Optional[str]
    _capsule_properties: List[str]
    _cc_email_recipients: List[EmailNotificationRecipientOutputV1]
    _contextual_text: Optional[str]
    _reply_to_email_recipients: List[EmailNotificationRecipientOutputV1]
    _report_format: Optional[str]
    _subject: Optional[str]
    _timezone: Optional[str]
    _to_email_recipients: List[EmailNotificationRecipientOutputV1]


    def __init__(
        self,
        bcc_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
        capsule_grouping: Optional[str] = None,
        capsule_properties: Optional[List[str]] = None,
        cc_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
        contextual_text: Optional[str] = None,
        reply_to_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
        report_format: Optional[str] = None,
        subject: Optional[str] = None,
        timezone: Optional[str] = None,
        to_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
    ) -> None: ...

    @property
    def bcc_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @bcc_email_recipients.setter
    def bcc_email_recipients(self, bcc_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    @property
    def capsule_grouping(self) -> Optional[str]: ...

    @capsule_grouping.setter
    def capsule_grouping(self, capsule_grouping: Optional[str]) -> None: ...

    @property
    def capsule_properties(self) -> List[str]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: List[str]) -> None: ...

    @property
    def cc_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @cc_email_recipients.setter
    def cc_email_recipients(self, cc_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    @property
    def contextual_text(self) -> Optional[str]: ...

    @contextual_text.setter
    def contextual_text(self, contextual_text: Optional[str]) -> None: ...

    @property
    def reply_to_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @reply_to_email_recipients.setter
    def reply_to_email_recipients(self, reply_to_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    @property
    def report_format(self) -> Optional[str]: ...

    @report_format.setter
    def report_format(self, report_format: Optional[str]) -> None: ...

    @property
    def subject(self) -> Optional[str]: ...

    @subject.setter
    def subject(self, subject: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def to_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @to_email_recipients.setter
    def to_email_recipients(self, to_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
