# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ServerStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _async_migrations_complete: Optional[bool]
    _async_migrations_semantic_version: Optional[str]
    _at_user_limit: Optional[bool]
    _configuration_options: Optional[List[ConfigurationOptionOutputSimpleV1]]
    _default_max_capsule_duration: Optional[ScalarValueOutputV1]
    _default_max_interpolation: Optional[ScalarValueOutputV1]
    _is_data_lab_available: Optional[bool]
    _priorities: Optional[List[PriorityV1]]
    _seeq_gpt_enabled: Optional[bool]
    _server_specs: Optional[List[ServerSpecOutputV1]]
    _time_zone: Optional[str]
    _version: Optional[str]


    def __init__(
        self,
        async_migrations_complete: Optional[bool] = None,
        async_migrations_semantic_version: Optional[str] = None,
        at_user_limit: Optional[bool] = False,
        configuration_options: Optional[List[ConfigurationOptionOutputSimpleV1]] = None,
        default_max_capsule_duration: Optional[ScalarValueOutputV1] = None,
        default_max_interpolation: Optional[ScalarValueOutputV1] = None,
        is_data_lab_available: Optional[bool] = False,
        priorities: Optional[List[PriorityV1]] = None,
        seeq_gpt_enabled: Optional[bool] = False,
        server_specs: Optional[List[ServerSpecOutputV1]] = None,
        time_zone: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def async_migrations_complete(self) -> Optional[bool]: ...

    @async_migrations_complete.setter
    def async_migrations_complete(self, async_migrations_complete: Optional[bool]) -> None: ...

    @property
    def async_migrations_semantic_version(self) -> Optional[str]: ...

    @async_migrations_semantic_version.setter
    def async_migrations_semantic_version(self, async_migrations_semantic_version: Optional[str]) -> None: ...

    @property
    def at_user_limit(self) -> Optional[bool]: ...

    @at_user_limit.setter
    def at_user_limit(self, at_user_limit: Optional[bool]) -> None: ...

    @property
    def configuration_options(self) -> Optional[List[ConfigurationOptionOutputSimpleV1]]: ...

    @configuration_options.setter
    def configuration_options(self, configuration_options: Optional[List[ConfigurationOptionOutputSimpleV1]]) -> None: ...

    @property
    def default_max_capsule_duration(self) -> Optional[ScalarValueOutputV1]: ...

    @default_max_capsule_duration.setter
    def default_max_capsule_duration(self, default_max_capsule_duration: Optional[ScalarValueOutputV1]) -> None: ...

    @property
    def default_max_interpolation(self) -> Optional[ScalarValueOutputV1]: ...

    @default_max_interpolation.setter
    def default_max_interpolation(self, default_max_interpolation: Optional[ScalarValueOutputV1]) -> None: ...

    @property
    def is_data_lab_available(self) -> Optional[bool]: ...

    @is_data_lab_available.setter
    def is_data_lab_available(self, is_data_lab_available: Optional[bool]) -> None: ...

    @property
    def priorities(self) -> Optional[List[PriorityV1]]: ...

    @priorities.setter
    def priorities(self, priorities: Optional[List[PriorityV1]]) -> None: ...

    @property
    def seeq_gpt_enabled(self) -> Optional[bool]: ...

    @seeq_gpt_enabled.setter
    def seeq_gpt_enabled(self, seeq_gpt_enabled: Optional[bool]) -> None: ...

    @property
    def server_specs(self) -> Optional[List[ServerSpecOutputV1]]: ...

    @server_specs.setter
    def server_specs(self, server_specs: Optional[List[ServerSpecOutputV1]]) -> None: ...

    @property
    def time_zone(self) -> Optional[str]: ...

    @time_zone.setter
    def time_zone(self, time_zone: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
