# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LogMessage(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _exception: Optional[str]
    _failure_reasons: Optional[List[str]]
    _formatted_level: Optional[str]
    _level: str
    _logger_name: Optional[str]
    _message: str
    _source: str
    _time: str
    _valid: Optional[bool]


    def __init__(
        self,
        exception: Optional[str] = None,
        failure_reasons: Optional[List[str]] = None,
        formatted_level: Optional[str] = None,
        level: Optional[str] = None,
        logger_name: Optional[str] = None,
        message: Optional[str] = None,
        source: Optional[str] = None,
        time: Optional[str] = None,
        valid: Optional[bool] = None,
    ) -> None: ...

    @property
    def exception(self) -> Optional[str]: ...

    @exception.setter
    def exception(self, exception: Optional[str]) -> None: ...

    @property
    def failure_reasons(self) -> Optional[List[str]]: ...

    @failure_reasons.setter
    def failure_reasons(self, failure_reasons: Optional[List[str]]) -> None: ...

    @property
    def formatted_level(self) -> Optional[str]: ...

    @formatted_level.setter
    def formatted_level(self, formatted_level: Optional[str]) -> None: ...

    @property
    def level(self) -> str: ...

    @level.setter
    def level(self, level: str) -> None: ...

    @property
    def logger_name(self) -> Optional[str]: ...

    @logger_name.setter
    def logger_name(self, logger_name: Optional[str]) -> None: ...

    @property
    def message(self) -> str: ...

    @message.setter
    def message(self, message: str) -> None: ...

    @property
    def source(self) -> str: ...

    @source.setter
    def source(self, source: str) -> None: ...

    @property
    def time(self) -> str: ...

    @time.setter
    def time(self, time: str) -> None: ...

    @property
    def valid(self) -> Optional[bool]: ...

    @valid.setter
    def valid(self, valid: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
