# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SignalMonitorInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _enabled: Optional[bool]
    _first_run_look_back: Optional[int]
    _frequency: str
    _name: str
    _query_range_look_ahead: Optional[int]
    _sample_event_types: Optional[List[str]]
    _scoped_to: Optional[str]
    _signal_ids: List[str]
    _timezone: Optional[str]


    def __init__(
        self,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        first_run_look_back: Optional[int] = None,
        frequency: Optional[str] = None,
        name: Optional[str] = None,
        query_range_look_ahead: Optional[int] = None,
        sample_event_types: Optional[List[str]] = None,
        scoped_to: Optional[str] = None,
        signal_ids: Optional[List[str]] = None,
        timezone: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def first_run_look_back(self) -> Optional[int]: ...

    @first_run_look_back.setter
    def first_run_look_back(self, first_run_look_back: Optional[int]) -> None: ...

    @property
    def frequency(self) -> str: ...

    @frequency.setter
    def frequency(self, frequency: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def query_range_look_ahead(self) -> Optional[int]: ...

    @query_range_look_ahead.setter
    def query_range_look_ahead(self, query_range_look_ahead: Optional[int]) -> None: ...

    @property
    def sample_event_types(self) -> Optional[List[str]]: ...

    @sample_event_types.setter
    def sample_event_types(self, sample_event_types: Optional[List[str]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def signal_ids(self) -> List[str]: ...

    @signal_ids.setter
    def signal_ids(self, signal_ids: List[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
