# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AssetTreeBatchInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _child_host_id: str
    _disable_asset_tree_index_update_during_sync: Optional[bool]
    _parent_host_id: str
    _relationships: Optional[List[AssetTreeSingleInputV1]]


    def __init__(
        self,
        child_host_id: Optional[str] = None,
        disable_asset_tree_index_update_during_sync: Optional[bool] = False,
        parent_host_id: Optional[str] = None,
        relationships: Optional[List[AssetTreeSingleInputV1]] = None,
    ) -> None: ...

    @property
    def child_host_id(self) -> str: ...

    @child_host_id.setter
    def child_host_id(self, child_host_id: str) -> None: ...

    @property
    def disable_asset_tree_index_update_during_sync(self) -> Optional[bool]: ...

    @disable_asset_tree_index_update_during_sync.setter
    def disable_asset_tree_index_update_during_sync(self, disable_asset_tree_index_update_during_sync: Optional[bool]) -> None: ...

    @property
    def parent_host_id(self) -> str: ...

    @parent_host_id.setter
    def parent_host_id(self, parent_host_id: str) -> None: ...

    @property
    def relationships(self) -> Optional[List[AssetTreeSingleInputV1]]: ...

    @relationships.setter
    def relationships(self, relationships: Optional[List[AssetTreeSingleInputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
