# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemParameterOfOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestors: Optional[List[ItemPreviewV1]]
    _has_active_children: Optional[bool]
    _has_children: Optional[bool]
    _id: str
    _is_archived: Optional[bool]
    _is_generated: Optional[bool]
    _is_redacted: Optional[bool]
    _name: str
    _parameter_of: Optional[List[ItemPreviewWithAssetsV1]]
    _translation_key: Optional[str]
    _type: str


    def __init__(
        self,
        ancestors: Optional[List[ItemPreviewV1]] = None,
        has_active_children: Optional[bool] = False,
        has_children: Optional[bool] = False,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_generated: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        name: Optional[str] = None,
        parameter_of: Optional[List[ItemPreviewWithAssetsV1]] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def ancestors(self) -> Optional[List[ItemPreviewV1]]: ...

    @ancestors.setter
    def ancestors(self, ancestors: Optional[List[ItemPreviewV1]]) -> None: ...

    @property
    def has_active_children(self) -> Optional[bool]: ...

    @has_active_children.setter
    def has_active_children(self, has_active_children: Optional[bool]) -> None: ...

    @property
    def has_children(self) -> Optional[bool]: ...

    @has_children.setter
    def has_children(self, has_children: Optional[bool]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_generated(self) -> Optional[bool]: ...

    @is_generated.setter
    def is_generated(self, is_generated: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def parameter_of(self) -> Optional[List[ItemPreviewWithAssetsV1]]: ...

    @parameter_of.setter
    def parameter_of(self, parameter_of: Optional[List[ItemPreviewWithAssetsV1]]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
