# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentMetaOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'draft': 'CustomAgentDraftInfoOutputV1',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'draft': 'draft',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, draft=None, updated_at=None):
        """
        CustomAgentMetaOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._draft = None
        self._updated_at = None

        if created_at is not None:
          self.created_at = created_at
        if draft is not None:
          self.draft = draft
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def created_at(self):
        """
        Gets the created_at of this CustomAgentMetaOutputV1.
        The time the custom agent was created

        :return: The created_at of this CustomAgentMetaOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this CustomAgentMetaOutputV1.
        The time the custom agent was created

        :param created_at: The created_at of this CustomAgentMetaOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def draft(self):
        """
        Gets the draft of this CustomAgentMetaOutputV1.

        :return: The draft of this CustomAgentMetaOutputV1.
        :rtype: CustomAgentDraftInfoOutputV1
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """
        Sets the draft of this CustomAgentMetaOutputV1.

        :param draft: The draft of this CustomAgentMetaOutputV1.
        :type: CustomAgentDraftInfoOutputV1
        """
        if draft is None:
            raise ValueError("Invalid value for `draft`, must not be `None`")

        self._draft = draft

    @property
    def updated_at(self):
        """
        Gets the updated_at of this CustomAgentMetaOutputV1.
        The time the custom agent (or visible draft) was last updated

        :return: The updated_at of this CustomAgentMetaOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this CustomAgentMetaOutputV1.
        The time the custom agent (or visible draft) was last updated

        :param updated_at: The updated_at of this CustomAgentMetaOutputV1.
        :type: str
        """
        if updated_at is None:
            raise ValueError("Invalid value for `updated_at`, must not be `None`")

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentMetaOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
