# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RadialRehydrationInstructionsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'selected_series_names': 'list[str]',
        'series_identifier': 'str',
        'time_key': 'str'
    }

    attribute_map = {
        'selected_series_names': 'selectedSeriesNames',
        'series_identifier': 'seriesIdentifier',
        'time_key': 'timeKey'
    }

    def __init__(self, selected_series_names=None, series_identifier=None, time_key=None):
        """
        RadialRehydrationInstructionsOutputV1 - a model defined in Swagger
        """

        self._selected_series_names = None
        self._series_identifier = None
        self._time_key = None

        if selected_series_names is not None:
          self.selected_series_names = selected_series_names
        if series_identifier is not None:
          self.series_identifier = series_identifier
        if time_key is not None:
          self.time_key = time_key

    @property
    def selected_series_names(self):
        """
        Gets the selected_series_names of this RadialRehydrationInstructionsOutputV1.
        Specific series names that are hydrated for the chart

        :return: The selected_series_names of this RadialRehydrationInstructionsOutputV1.
        :rtype: list[str]
        """
        return self._selected_series_names

    @selected_series_names.setter
    def selected_series_names(self, selected_series_names):
        """
        Sets the selected_series_names of this RadialRehydrationInstructionsOutputV1.
        Specific series names that are hydrated for the chart

        :param selected_series_names: The selected_series_names of this RadialRehydrationInstructionsOutputV1.
        :type: list[str]
        """
        if selected_series_names is None:
            raise ValueError("Invalid value for `selected_series_names`, must not be `None`")

        self._selected_series_names = selected_series_names

    @property
    def series_identifier(self):
        """
        Gets the series_identifier of this RadialRehydrationInstructionsOutputV1.
        Identifier that maps radial data to chart options

        :return: The series_identifier of this RadialRehydrationInstructionsOutputV1.
        :rtype: str
        """
        return self._series_identifier

    @series_identifier.setter
    def series_identifier(self, series_identifier):
        """
        Sets the series_identifier of this RadialRehydrationInstructionsOutputV1.
        Identifier that maps radial data to chart options

        :param series_identifier: The series_identifier of this RadialRehydrationInstructionsOutputV1.
        :type: str
        """
        if series_identifier is None:
            raise ValueError("Invalid value for `series_identifier`, must not be `None`")

        self._series_identifier = series_identifier

    @property
    def time_key(self):
        """
        Gets the time_key of this RadialRehydrationInstructionsOutputV1.
        The data column used as the time key for radial chart rehydration

        :return: The time_key of this RadialRehydrationInstructionsOutputV1.
        :rtype: str
        """
        return self._time_key

    @time_key.setter
    def time_key(self, time_key):
        """
        Sets the time_key of this RadialRehydrationInstructionsOutputV1.
        The data column used as the time key for radial chart rehydration

        :param time_key: The time_key of this RadialRehydrationInstructionsOutputV1.
        :type: str
        """
        if time_key is None:
            raise ValueError("Invalid value for `time_key`, must not be `None`")

        self._time_key = time_key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RadialRehydrationInstructionsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
