from __future__ import annotations

from typing import List

# `seeq` is a namespace package (PEP 420). This stub file exists to mark the
# distribution as typed (PEP 561) and to make type checkers treat `seeq` as a package.
__path__: List[str]

