# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_name: str
    _agent_version_required: Optional[str]
    _connection_id: str
    _connection_message: Optional[str]
    _connector_developer_name: Optional[str]
    _connector_developer_support_url: Optional[str]
    _connector_name: Optional[str]
    _created_at: Optional[str]
    _datasource_managed: Optional[bool]
    _disabled_at: Optional[str]
    _disabled_by: Optional[str]
    _has_error: Optional[bool]
    _last_successful_connected_at: Optional[str]
    _name: str
    _status: Optional[str]
    _sync_status: Optional[str]
    _version: Optional[str]


    def __init__(
        self,
        agent_name: Optional[str] = None,
        agent_version_required: Optional[str] = None,
        connection_id: Optional[str] = None,
        connection_message: Optional[str] = None,
        connector_developer_name: Optional[str] = None,
        connector_developer_support_url: Optional[str] = None,
        connector_name: Optional[str] = None,
        created_at: Optional[str] = None,
        datasource_managed: Optional[bool] = False,
        disabled_at: Optional[str] = None,
        disabled_by: Optional[str] = None,
        has_error: Optional[bool] = False,
        last_successful_connected_at: Optional[str] = None,
        name: Optional[str] = None,
        status: Optional[str] = None,
        sync_status: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_name(self) -> str: ...

    @agent_name.setter
    def agent_name(self, agent_name: str) -> None: ...

    @property
    def agent_version_required(self) -> Optional[str]: ...

    @agent_version_required.setter
    def agent_version_required(self, agent_version_required: Optional[str]) -> None: ...

    @property
    def connection_id(self) -> str: ...

    @connection_id.setter
    def connection_id(self, connection_id: str) -> None: ...

    @property
    def connection_message(self) -> Optional[str]: ...

    @connection_message.setter
    def connection_message(self, connection_message: Optional[str]) -> None: ...

    @property
    def connector_developer_name(self) -> Optional[str]: ...

    @connector_developer_name.setter
    def connector_developer_name(self, connector_developer_name: Optional[str]) -> None: ...

    @property
    def connector_developer_support_url(self) -> Optional[str]: ...

    @connector_developer_support_url.setter
    def connector_developer_support_url(self, connector_developer_support_url: Optional[str]) -> None: ...

    @property
    def connector_name(self) -> Optional[str]: ...

    @connector_name.setter
    def connector_name(self, connector_name: Optional[str]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def datasource_managed(self) -> Optional[bool]: ...

    @datasource_managed.setter
    def datasource_managed(self, datasource_managed: Optional[bool]) -> None: ...

    @property
    def disabled_at(self) -> Optional[str]: ...

    @disabled_at.setter
    def disabled_at(self, disabled_at: Optional[str]) -> None: ...

    @property
    def disabled_by(self) -> Optional[str]: ...

    @disabled_by.setter
    def disabled_by(self, disabled_by: Optional[str]) -> None: ...

    @property
    def has_error(self) -> Optional[bool]: ...

    @has_error.setter
    def has_error(self, has_error: Optional[bool]) -> None: ...

    @property
    def last_successful_connected_at(self) -> Optional[str]: ...

    @last_successful_connected_at.setter
    def last_successful_connected_at(self, last_successful_connected_at: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def sync_status(self) -> Optional[str]: ...

    @sync_status.setter
    def sync_status(self, sync_status: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
