# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LastRunStateOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _condition_guid: str
    _cursor_key: Optional[int]
    _earliest_uncertain_end_time_capsule_start: Optional[int]
    _error_count: Optional[int]
    _id_property: Optional[str]
    _last_error: Optional[str]
    _last_error_time_created: Optional[int]
    _uncertain_capsule_ids: Optional[List[str]]


    def __init__(
        self,
        condition_guid: Optional[str] = None,
        cursor_key: Optional[int] = None,
        earliest_uncertain_end_time_capsule_start: Optional[int] = None,
        error_count: Optional[int] = None,
        id_property: Optional[str] = None,
        last_error: Optional[str] = None,
        last_error_time_created: Optional[int] = None,
        uncertain_capsule_ids: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def condition_guid(self) -> str: ...

    @condition_guid.setter
    def condition_guid(self, condition_guid: str) -> None: ...

    @property
    def cursor_key(self) -> Optional[int]: ...

    @cursor_key.setter
    def cursor_key(self, cursor_key: Optional[int]) -> None: ...

    @property
    def earliest_uncertain_end_time_capsule_start(self) -> Optional[int]: ...

    @earliest_uncertain_end_time_capsule_start.setter
    def earliest_uncertain_end_time_capsule_start(self, earliest_uncertain_end_time_capsule_start: Optional[int]) -> None: ...

    @property
    def error_count(self) -> Optional[int]: ...

    @error_count.setter
    def error_count(self, error_count: Optional[int]) -> None: ...

    @property
    def id_property(self) -> Optional[str]: ...

    @id_property.setter
    def id_property(self, id_property: Optional[str]) -> None: ...

    @property
    def last_error(self) -> Optional[str]: ...

    @last_error.setter
    def last_error(self, last_error: Optional[str]) -> None: ...

    @property
    def last_error_time_created(self) -> Optional[int]: ...

    @last_error_time_created.setter
    def last_error_time_created(self, last_error_time_created: Optional[int]) -> None: ...

    @property
    def uncertain_capsule_ids(self) -> Optional[List[str]]: ...

    @uncertain_capsule_ids.setter
    def uncertain_capsule_ids(self, uncertain_capsule_ids: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
