# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class SubscriptionsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def get_channels(
        self,
        **kwargs: Any,
    ) -> GetChannelsOutputV1: ...

    def get_channels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def subscribe(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def subscribe_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unsubscribe(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def unsubscribe_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_subscription(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def update_subscription_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
