# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ServerSpecOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _component_name: Optional[str]
    _error: Optional[bool]
    _message: Optional[str]
    _system_spec_value: Optional[str]
    _warning: Optional[bool]


    def __init__(
        self,
        component_name: Optional[str] = None,
        error: Optional[bool] = False,
        message: Optional[str] = None,
        system_spec_value: Optional[str] = None,
        warning: Optional[bool] = False,
    ) -> None: ...

    @property
    def component_name(self) -> Optional[str]: ...

    @component_name.setter
    def component_name(self, component_name: Optional[str]) -> None: ...

    @property
    def error(self) -> Optional[bool]: ...

    @error.setter
    def error(self, error: Optional[bool]) -> None: ...

    @property
    def message(self) -> Optional[str]: ...

    @message.setter
    def message(self, message: Optional[str]) -> None: ...

    @property
    def system_spec_value(self) -> Optional[str]: ...

    @system_spec_value.setter
    def system_spec_value(self, system_spec_value: Optional[str]) -> None: ...

    @property
    def warning(self) -> Optional[bool]: ...

    @warning.setter
    def warning(self, warning: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
