# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FoldedStackNodeV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _children: List[FoldedStackNodeV1]
    _interval_end: Optional[int]
    _interval_start: Optional[int]
    _name: str
    _properties: Dict[str, str]
    _value: int


    def __init__(
        self,
        children: Optional[List[FoldedStackNodeV1]] = None,
        interval_end: Optional[int] = None,
        interval_start: Optional[int] = None,
        name: Optional[str] = None,
        properties: Optional[Dict[str, str]] = None,
        value: Optional[int] = None,
    ) -> None: ...

    @property
    def children(self) -> List[FoldedStackNodeV1]: ...

    @children.setter
    def children(self, children: List[FoldedStackNodeV1]) -> None: ...

    @property
    def interval_end(self) -> Optional[int]: ...

    @interval_end.setter
    def interval_end(self, interval_end: Optional[int]) -> None: ...

    @property
    def interval_start(self) -> Optional[int]: ...

    @interval_start.setter
    def interval_start(self, interval_start: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def properties(self) -> Dict[str, str]: ...

    @properties.setter
    def properties(self, properties: Dict[str, str]) -> None: ...

    @property
    def value(self) -> int: ...

    @value.setter
    def value(self, value: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
