# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class HierarchiesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputV1: ...

    def create_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchies(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputListV1: ...

    def get_hierarchies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputV1: ...

    def get_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchy_node(
        self,
        **kwargs: Any,
    ) -> HierarchyNodeWithPathOutputV1: ...

    def get_hierarchy_node_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchy_nodes(
        self,
        **kwargs: Any,
    ) -> HierarchyNodeOutputListV1: ...

    def get_hierarchy_nodes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search_hierarchy_node(
        self,
        **kwargs: Any,
    ) -> HierarchyNodeWithPathOutputV1: ...

    def search_hierarchy_node_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputV1: ...

    def update_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyValidationOutputV1: ...

    def validate_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_hierarchy_input(
        self,
        **kwargs: Any,
    ) -> HierarchyValidationOutputV1: ...

    def validate_hierarchy_input_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
