# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AddOnToolOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _icon_class: str
    _id: str
    _in_development: Optional[bool]
    _installer: Optional[IdentityPreviewV1]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _launch_location: str
    _link_type: str
    _name: str
    _reuse_window: bool
    _sort_key: str
    _status_message: Optional[str]
    _target_url: str
    _translation_key: Optional[str]
    _type: str
    _window_details: str


    def __init__(
        self,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        icon_class: Optional[str] = None,
        id: Optional[str] = None,
        in_development: Optional[bool] = None,
        installer: Optional[IdentityPreviewV1] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        launch_location: Optional[str] = None,
        link_type: Optional[str] = None,
        name: Optional[str] = None,
        reuse_window: Optional[bool] = False,
        sort_key: Optional[str] = None,
        status_message: Optional[str] = None,
        target_url: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        window_details: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def icon_class(self) -> str: ...

    @icon_class.setter
    def icon_class(self, icon_class: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def in_development(self) -> Optional[bool]: ...

    @in_development.setter
    def in_development(self, in_development: Optional[bool]) -> None: ...

    @property
    def installer(self) -> Optional[IdentityPreviewV1]: ...

    @installer.setter
    def installer(self, installer: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def launch_location(self) -> str: ...

    @launch_location.setter
    def launch_location(self, launch_location: str) -> None: ...

    @property
    def link_type(self) -> str: ...

    @link_type.setter
    def link_type(self, link_type: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def reuse_window(self) -> bool: ...

    @reuse_window.setter
    def reuse_window(self, reuse_window: bool) -> None: ...

    @property
    def sort_key(self) -> str: ...

    @sort_key.setter
    def sort_key(self, sort_key: str) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def target_url(self) -> str: ...

    @target_url.setter
    def target_url(self, target_url: str) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def window_details(self) -> str: ...

    @window_details.setter
    def window_details(self, window_details: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
