# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ScheduledNotebookInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _enabled: Optional[bool]
    _file_path: str
    _label: Optional[str]
    _notify_on_automatic_unschedule: Optional[bool]
    _notify_on_skipped_execution: Optional[bool]
    _schedules: Optional[List[ScheduleInputV1]]
    _timezone: Optional[str]
    _user_id: Optional[str]


    def __init__(
        self,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        file_path: Optional[str] = None,
        label: Optional[str] = None,
        notify_on_automatic_unschedule: Optional[bool] = True,
        notify_on_skipped_execution: Optional[bool] = True,
        schedules: Optional[List[ScheduleInputV1]] = None,
        timezone: Optional[str] = None,
        user_id: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def file_path(self) -> str: ...

    @file_path.setter
    def file_path(self, file_path: str) -> None: ...

    @property
    def label(self) -> Optional[str]: ...

    @label.setter
    def label(self, label: Optional[str]) -> None: ...

    @property
    def notify_on_automatic_unschedule(self) -> Optional[bool]: ...

    @notify_on_automatic_unschedule.setter
    def notify_on_automatic_unschedule(self, notify_on_automatic_unschedule: Optional[bool]) -> None: ...

    @property
    def notify_on_skipped_execution(self) -> Optional[bool]: ...

    @notify_on_skipped_execution.setter
    def notify_on_skipped_execution(self, notify_on_skipped_execution: Optional[bool]) -> None: ...

    @property
    def schedules(self) -> Optional[List[ScheduleInputV1]]: ...

    @schedules.setter
    def schedules(self, schedules: Optional[List[ScheduleInputV1]]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def user_id(self) -> Optional[str]: ...

    @user_id.setter
    def user_id(self, user_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
