# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContentInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _analysis_view_type: Optional[str]
    _archived: Optional[bool]
    _asset_selection_id: Optional[str]
    _date_range_id: Optional[str]
    _description: Optional[str]
    _fill_to_fit: Optional[bool]
    _height: int
    _hide_uncertainty: Optional[bool]
    _name: str
    _react: Optional[bool]
    _report_id: Optional[str]
    _scale: Optional[float]
    _selector: Optional[str]
    _summary_type: Optional[str]
    _summary_value: Optional[str]
    _timezone: Optional[str]
    _width: int
    _worksheet_id: str
    _workstep_id: str


    def __init__(
        self,
        analysis_view_type: Optional[str] = None,
        archived: Optional[bool] = False,
        asset_selection_id: Optional[str] = None,
        date_range_id: Optional[str] = None,
        description: Optional[str] = None,
        fill_to_fit: Optional[bool] = False,
        height: Optional[int] = None,
        hide_uncertainty: Optional[bool] = None,
        name: Optional[str] = None,
        react: Optional[bool] = False,
        report_id: Optional[str] = None,
        scale: Optional[float] = None,
        selector: Optional[str] = None,
        summary_type: Optional[str] = None,
        summary_value: Optional[str] = None,
        timezone: Optional[str] = None,
        width: Optional[int] = None,
        worksheet_id: Optional[str] = None,
        workstep_id: Optional[str] = None,
    ) -> None: ...

    @property
    def analysis_view_type(self) -> Optional[str]: ...

    @analysis_view_type.setter
    def analysis_view_type(self, analysis_view_type: Optional[str]) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def asset_selection_id(self) -> Optional[str]: ...

    @asset_selection_id.setter
    def asset_selection_id(self, asset_selection_id: Optional[str]) -> None: ...

    @property
    def date_range_id(self) -> Optional[str]: ...

    @date_range_id.setter
    def date_range_id(self, date_range_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def fill_to_fit(self) -> Optional[bool]: ...

    @fill_to_fit.setter
    def fill_to_fit(self, fill_to_fit: Optional[bool]) -> None: ...

    @property
    def height(self) -> int: ...

    @height.setter
    def height(self, height: int) -> None: ...

    @property
    def hide_uncertainty(self) -> Optional[bool]: ...

    @hide_uncertainty.setter
    def hide_uncertainty(self, hide_uncertainty: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def react(self) -> Optional[bool]: ...

    @react.setter
    def react(self, react: Optional[bool]) -> None: ...

    @property
    def report_id(self) -> Optional[str]: ...

    @report_id.setter
    def report_id(self, report_id: Optional[str]) -> None: ...

    @property
    def scale(self) -> Optional[float]: ...

    @scale.setter
    def scale(self, scale: Optional[float]) -> None: ...

    @property
    def selector(self) -> Optional[str]: ...

    @selector.setter
    def selector(self, selector: Optional[str]) -> None: ...

    @property
    def summary_type(self) -> Optional[str]: ...

    @summary_type.setter
    def summary_type(self, summary_type: Optional[str]) -> None: ...

    @property
    def summary_value(self) -> Optional[str]: ...

    @summary_value.setter
    def summary_value(self, summary_value: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def width(self) -> int: ...

    @width.setter
    def width(self, width: int) -> None: ...

    @property
    def worksheet_id(self) -> str: ...

    @worksheet_id.setter
    def worksheet_id(self, worksheet_id: str) -> None: ...

    @property
    def workstep_id(self) -> str: ...

    @workstep_id.setter
    def workstep_id(self, workstep_id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
