# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class UserGroupsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_identity_to_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def add_identity_to_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def archive_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def create_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def disable_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def disable_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_capability_user_groups(
        self,
        **kwargs: Any,
    ) -> IdentityPreviewListV1: ...

    def get_capability_user_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def get_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user_groups(
        self,
        **kwargs: Any,
    ) -> IdentityPreviewListV1: ...

    def get_user_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_user_groups(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def put_user_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_identity_from_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def remove_identity_from_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_user_group(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def remove_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def update_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
