# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DisplayOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _data_id: str
    _datasource_class: str
    _datasource_id: str
    _description: Optional[str]
    _effective_permissions: PermissionsV1
    _id: str
    _is_archived: Optional[bool]
    _name: str
    _scoped_to: Optional[str]
    _status_message: str
    _swap: Optional[SwapOutputV1]
    _sync_token: str
    _template: DisplayTemplateOutputV1
    _type: str


    def __init__(
        self,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = None,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        swap: Optional[SwapOutputV1] = None,
        sync_token: Optional[str] = None,
        template: Optional[DisplayTemplateOutputV1] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def data_id(self) -> str: ...

    @data_id.setter
    def data_id(self, data_id: str) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> PermissionsV1: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: PermissionsV1) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> str: ...

    @status_message.setter
    def status_message(self, status_message: str) -> None: ...

    @property
    def swap(self) -> Optional[SwapOutputV1]: ...

    @swap.setter
    def swap(self, swap: Optional[SwapOutputV1]) -> None: ...

    @property
    def sync_token(self) -> str: ...

    @sync_token.setter
    def sync_token(self, sync_token: str) -> None: ...

    @property
    def template(self) -> DisplayTemplateOutputV1: ...

    @template.setter
    def template(self, template: DisplayTemplateOutputV1) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
