# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AddOnPreviewV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _add_on_identifier: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _id: Optional[str]
    _in_development: Optional[bool]
    _installer: Optional[IdentityPreviewV1]


    def __init__(
        self,
        add_on_identifier: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        in_development: Optional[bool] = None,
        installer: Optional[IdentityPreviewV1] = None,
    ) -> None: ...

    @property
    def add_on_identifier(self) -> Optional[str]: ...

    @add_on_identifier.setter
    def add_on_identifier(self, add_on_identifier: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def in_development(self) -> Optional[bool]: ...

    @in_development.setter
    def in_development(self, in_development: Optional[bool]) -> None: ...

    @property
    def installer(self) -> Optional[IdentityPreviewV1]: ...

    @installer.setter
    def installer(self, installer: Optional[IdentityPreviewV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
