# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConfigurationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _configuration_options: List[ConfigurationOptionOutputV1]
    _limit: Optional[int]
    _next: Optional[str]
    _offset: Optional[int]
    _prev: Optional[str]
    _status_message: Optional[str]
    _total_results: int


    def __init__(
        self,
        configuration_options: Optional[List[ConfigurationOptionOutputV1]] = None,
        limit: Optional[int] = None,
        next: Optional[str] = None,
        offset: Optional[int] = None,
        prev: Optional[str] = None,
        status_message: Optional[str] = None,
        total_results: Optional[int] = None,
    ) -> None: ...

    @property
    def configuration_options(self) -> List[ConfigurationOptionOutputV1]: ...

    @configuration_options.setter
    def configuration_options(self, configuration_options: List[ConfigurationOptionOutputV1]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def next(self) -> Optional[str]: ...

    @next.setter
    def next(self, next: Optional[str]) -> None: ...

    @property
    def offset(self) -> Optional[int]: ...

    @offset.setter
    def offset(self, offset: Optional[int]) -> None: ...

    @property
    def prev(self) -> Optional[str]: ...

    @prev.setter
    def prev(self, prev: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def total_results(self) -> int: ...

    @total_results.setter
    def total_results(self, total_results: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
