# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ExportItemsOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _autoupdate_time_range: Optional[bool]
    _capsule_time: Optional[bool]
    _chain_view: Optional[bool]
    _created_at: Optional[str]
    _creator: Optional[IdentityPreviewV1]
    _export_capsules: Optional[bool]
    _export_name: Optional[str]
    _exported_item_schema: Optional[str]
    _grid_enabled: Optional[bool]
    _grid_origin: Optional[str]
    _grid_size: Optional[str]
    _href: Optional[str]
    _href_legacy: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _items: List[ExportItemV1]
    _name: Optional[str]
    _original_timestamps_enabled: Optional[bool]
    _scoped_to: Optional[str]
    _status_message: Optional[str]
    _swap_in: Optional[str]
    _swap_out: Optional[str]
    _time_zone: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        autoupdate_time_range: Optional[bool] = False,
        capsule_time: Optional[bool] = False,
        chain_view: Optional[bool] = False,
        created_at: Optional[str] = None,
        creator: Optional[IdentityPreviewV1] = None,
        export_capsules: Optional[bool] = False,
        export_name: Optional[str] = None,
        exported_item_schema: Optional[str] = None,
        grid_enabled: Optional[bool] = False,
        grid_origin: Optional[str] = None,
        grid_size: Optional[str] = None,
        href: Optional[str] = None,
        href_legacy: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        items: Optional[List[ExportItemV1]] = None,
        name: Optional[str] = None,
        original_timestamps_enabled: Optional[bool] = False,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        swap_in: Optional[str] = None,
        swap_out: Optional[str] = None,
        time_zone: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def autoupdate_time_range(self) -> Optional[bool]: ...

    @autoupdate_time_range.setter
    def autoupdate_time_range(self, autoupdate_time_range: Optional[bool]) -> None: ...

    @property
    def capsule_time(self) -> Optional[bool]: ...

    @capsule_time.setter
    def capsule_time(self, capsule_time: Optional[bool]) -> None: ...

    @property
    def chain_view(self) -> Optional[bool]: ...

    @chain_view.setter
    def chain_view(self, chain_view: Optional[bool]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator(self) -> Optional[IdentityPreviewV1]: ...

    @creator.setter
    def creator(self, creator: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def export_capsules(self) -> Optional[bool]: ...

    @export_capsules.setter
    def export_capsules(self, export_capsules: Optional[bool]) -> None: ...

    @property
    def export_name(self) -> Optional[str]: ...

    @export_name.setter
    def export_name(self, export_name: Optional[str]) -> None: ...

    @property
    def exported_item_schema(self) -> Optional[str]: ...

    @exported_item_schema.setter
    def exported_item_schema(self, exported_item_schema: Optional[str]) -> None: ...

    @property
    def grid_enabled(self) -> Optional[bool]: ...

    @grid_enabled.setter
    def grid_enabled(self, grid_enabled: Optional[bool]) -> None: ...

    @property
    def grid_origin(self) -> Optional[str]: ...

    @grid_origin.setter
    def grid_origin(self, grid_origin: Optional[str]) -> None: ...

    @property
    def grid_size(self) -> Optional[str]: ...

    @grid_size.setter
    def grid_size(self, grid_size: Optional[str]) -> None: ...

    @property
    def href(self) -> Optional[str]: ...

    @href.setter
    def href(self, href: Optional[str]) -> None: ...

    @property
    def href_legacy(self) -> Optional[str]: ...

    @href_legacy.setter
    def href_legacy(self, href_legacy: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def items(self) -> List[ExportItemV1]: ...

    @items.setter
    def items(self, items: List[ExportItemV1]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def original_timestamps_enabled(self) -> Optional[bool]: ...

    @original_timestamps_enabled.setter
    def original_timestamps_enabled(self, original_timestamps_enabled: Optional[bool]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def swap_in(self) -> Optional[str]: ...

    @swap_in.setter
    def swap_in(self, swap_in: Optional[str]) -> None: ...

    @property
    def swap_out(self) -> Optional[str]: ...

    @swap_out.setter
    def swap_out(self, swap_out: Optional[str]) -> None: ...

    @property
    def time_zone(self) -> Optional[str]: ...

    @time_zone.setter
    def time_zone(self, time_zone: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
