# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ColumnRuleInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestor: Optional[ColumnRuleAncestorInputV1]
    _asset_creator: Optional[ColumnRuleAssetCreatorInputV1]
    _concat_columns: Optional[ColumnRuleConcatInputV1]
    _constant: Optional[ColumnRuleConstantInputV1]
    _context_condition: Optional[ColumnRuleContextConditionInputV1]
    _datasource: Optional[ColumnRuleDatasourceInputV1]
    _descendant: Optional[ColumnRuleDescendantInputV1]
    _descendant_search: Optional[ColumnRuleDescendantSearchInputV1]
    _event_asset_creator: Optional[ColumnRuleEventAssetCreatorInputV1]
    _event_property: Optional[ColumnRuleEventPropertyInputV1]
    _find_descendant: Optional[ColumnRuleFindDescendantInputV1]
    _find_property: Optional[ColumnRuleFindPropertyInputV1]
    _formula_creator: Optional[ColumnRuleFormulaCreatorInputV1]
    _get_item_property: Optional[ColumnRuleGetItemPropertyInputV1]
    _item_search: Optional[ColumnRuleItemSearchInputV1]
    _item_type: Optional[ColumnRuleItemTypeInputV1]
    _manager: Optional[ColumnRuleManagerInputV1]
    _path: Optional[ColumnRulePathInputV1]
    _path_search: Optional[ColumnRulePathSearchInputV1]
    _preserve_existing: Optional[ColumnRulePreserveExistingInputV1]
    _scalar_creator: Optional[ColumnRuleScalarCreatorInputV1]
    _search_ancestor: Optional[ColumnRuleSearchAncestorInputV1]
    _set_item_property: Optional[ColumnRuleSetItemPropertyInputV1]
    _text_extractor: Optional[ColumnRuleTextExtractorInputV1]
    _text_replacement: Optional[ColumnRuleTextReplacementInputV1]
    _tree_path_creator: Optional[ColumnRuleTreePathCreatorInputV1]


    def __init__(
        self,
        ancestor: Optional[ColumnRuleAncestorInputV1] = None,
        asset_creator: Optional[ColumnRuleAssetCreatorInputV1] = None,
        concat_columns: Optional[ColumnRuleConcatInputV1] = None,
        constant: Optional[ColumnRuleConstantInputV1] = None,
        context_condition: Optional[ColumnRuleContextConditionInputV1] = None,
        datasource: Optional[ColumnRuleDatasourceInputV1] = None,
        descendant: Optional[ColumnRuleDescendantInputV1] = None,
        descendant_search: Optional[ColumnRuleDescendantSearchInputV1] = None,
        event_asset_creator: Optional[ColumnRuleEventAssetCreatorInputV1] = None,
        event_property: Optional[ColumnRuleEventPropertyInputV1] = None,
        find_descendant: Optional[ColumnRuleFindDescendantInputV1] = None,
        find_property: Optional[ColumnRuleFindPropertyInputV1] = None,
        formula_creator: Optional[ColumnRuleFormulaCreatorInputV1] = None,
        get_item_property: Optional[ColumnRuleGetItemPropertyInputV1] = None,
        item_search: Optional[ColumnRuleItemSearchInputV1] = None,
        item_type: Optional[ColumnRuleItemTypeInputV1] = None,
        manager: Optional[ColumnRuleManagerInputV1] = None,
        path: Optional[ColumnRulePathInputV1] = None,
        path_search: Optional[ColumnRulePathSearchInputV1] = None,
        preserve_existing: Optional[ColumnRulePreserveExistingInputV1] = None,
        scalar_creator: Optional[ColumnRuleScalarCreatorInputV1] = None,
        search_ancestor: Optional[ColumnRuleSearchAncestorInputV1] = None,
        set_item_property: Optional[ColumnRuleSetItemPropertyInputV1] = None,
        text_extractor: Optional[ColumnRuleTextExtractorInputV1] = None,
        text_replacement: Optional[ColumnRuleTextReplacementInputV1] = None,
        tree_path_creator: Optional[ColumnRuleTreePathCreatorInputV1] = None,
    ) -> None: ...

    @property
    def ancestor(self) -> Optional[ColumnRuleAncestorInputV1]: ...

    @ancestor.setter
    def ancestor(self, ancestor: Optional[ColumnRuleAncestorInputV1]) -> None: ...

    @property
    def asset_creator(self) -> Optional[ColumnRuleAssetCreatorInputV1]: ...

    @asset_creator.setter
    def asset_creator(self, asset_creator: Optional[ColumnRuleAssetCreatorInputV1]) -> None: ...

    @property
    def concat_columns(self) -> Optional[ColumnRuleConcatInputV1]: ...

    @concat_columns.setter
    def concat_columns(self, concat_columns: Optional[ColumnRuleConcatInputV1]) -> None: ...

    @property
    def constant(self) -> Optional[ColumnRuleConstantInputV1]: ...

    @constant.setter
    def constant(self, constant: Optional[ColumnRuleConstantInputV1]) -> None: ...

    @property
    def context_condition(self) -> Optional[ColumnRuleContextConditionInputV1]: ...

    @context_condition.setter
    def context_condition(self, context_condition: Optional[ColumnRuleContextConditionInputV1]) -> None: ...

    @property
    def datasource(self) -> Optional[ColumnRuleDatasourceInputV1]: ...

    @datasource.setter
    def datasource(self, datasource: Optional[ColumnRuleDatasourceInputV1]) -> None: ...

    @property
    def descendant(self) -> Optional[ColumnRuleDescendantInputV1]: ...

    @descendant.setter
    def descendant(self, descendant: Optional[ColumnRuleDescendantInputV1]) -> None: ...

    @property
    def descendant_search(self) -> Optional[ColumnRuleDescendantSearchInputV1]: ...

    @descendant_search.setter
    def descendant_search(self, descendant_search: Optional[ColumnRuleDescendantSearchInputV1]) -> None: ...

    @property
    def event_asset_creator(self) -> Optional[ColumnRuleEventAssetCreatorInputV1]: ...

    @event_asset_creator.setter
    def event_asset_creator(self, event_asset_creator: Optional[ColumnRuleEventAssetCreatorInputV1]) -> None: ...

    @property
    def event_property(self) -> Optional[ColumnRuleEventPropertyInputV1]: ...

    @event_property.setter
    def event_property(self, event_property: Optional[ColumnRuleEventPropertyInputV1]) -> None: ...

    @property
    def find_descendant(self) -> Optional[ColumnRuleFindDescendantInputV1]: ...

    @find_descendant.setter
    def find_descendant(self, find_descendant: Optional[ColumnRuleFindDescendantInputV1]) -> None: ...

    @property
    def find_property(self) -> Optional[ColumnRuleFindPropertyInputV1]: ...

    @find_property.setter
    def find_property(self, find_property: Optional[ColumnRuleFindPropertyInputV1]) -> None: ...

    @property
    def formula_creator(self) -> Optional[ColumnRuleFormulaCreatorInputV1]: ...

    @formula_creator.setter
    def formula_creator(self, formula_creator: Optional[ColumnRuleFormulaCreatorInputV1]) -> None: ...

    @property
    def get_item_property(self) -> Optional[ColumnRuleGetItemPropertyInputV1]: ...

    @get_item_property.setter
    def get_item_property(self, get_item_property: Optional[ColumnRuleGetItemPropertyInputV1]) -> None: ...

    @property
    def item_search(self) -> Optional[ColumnRuleItemSearchInputV1]: ...

    @item_search.setter
    def item_search(self, item_search: Optional[ColumnRuleItemSearchInputV1]) -> None: ...

    @property
    def item_type(self) -> Optional[ColumnRuleItemTypeInputV1]: ...

    @item_type.setter
    def item_type(self, item_type: Optional[ColumnRuleItemTypeInputV1]) -> None: ...

    @property
    def manager(self) -> Optional[ColumnRuleManagerInputV1]: ...

    @manager.setter
    def manager(self, manager: Optional[ColumnRuleManagerInputV1]) -> None: ...

    @property
    def path(self) -> Optional[ColumnRulePathInputV1]: ...

    @path.setter
    def path(self, path: Optional[ColumnRulePathInputV1]) -> None: ...

    @property
    def path_search(self) -> Optional[ColumnRulePathSearchInputV1]: ...

    @path_search.setter
    def path_search(self, path_search: Optional[ColumnRulePathSearchInputV1]) -> None: ...

    @property
    def preserve_existing(self) -> Optional[ColumnRulePreserveExistingInputV1]: ...

    @preserve_existing.setter
    def preserve_existing(self, preserve_existing: Optional[ColumnRulePreserveExistingInputV1]) -> None: ...

    @property
    def scalar_creator(self) -> Optional[ColumnRuleScalarCreatorInputV1]: ...

    @scalar_creator.setter
    def scalar_creator(self, scalar_creator: Optional[ColumnRuleScalarCreatorInputV1]) -> None: ...

    @property
    def search_ancestor(self) -> Optional[ColumnRuleSearchAncestorInputV1]: ...

    @search_ancestor.setter
    def search_ancestor(self, search_ancestor: Optional[ColumnRuleSearchAncestorInputV1]) -> None: ...

    @property
    def set_item_property(self) -> Optional[ColumnRuleSetItemPropertyInputV1]: ...

    @set_item_property.setter
    def set_item_property(self, set_item_property: Optional[ColumnRuleSetItemPropertyInputV1]) -> None: ...

    @property
    def text_extractor(self) -> Optional[ColumnRuleTextExtractorInputV1]: ...

    @text_extractor.setter
    def text_extractor(self, text_extractor: Optional[ColumnRuleTextExtractorInputV1]) -> None: ...

    @property
    def text_replacement(self) -> Optional[ColumnRuleTextReplacementInputV1]: ...

    @text_replacement.setter
    def text_replacement(self, text_replacement: Optional[ColumnRuleTextReplacementInputV1]) -> None: ...

    @property
    def tree_path_creator(self) -> Optional[ColumnRuleTreePathCreatorInputV1]: ...

    @tree_path_creator.setter
    def tree_path_creator(self, tree_path_creator: Optional[ColumnRuleTreePathCreatorInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
