# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class AccessKeysApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_key(
        self,
        **kwargs: Any,
    ) -> AccessKeyOutputV1: ...

    def create_key_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_key(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_key_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_keys(
        self,
        **kwargs: Any,
    ) -> AccessKeyOutputListV1: ...

    def get_keys_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
