# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConditionTableInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _capsule_properties: Optional[List[str]]
    _condition_properties: Optional[List[str]]
    _condition_source: ConditionSourceV1
    _end: Value
    _filter: Optional[Filter]
    _include_asset_column: Optional[bool]
    _limit: int
    _start: Value


    def __init__(
        self,
        capsule_properties: Optional[List[str]] = None,
        condition_properties: Optional[List[str]] = None,
        condition_source: Optional[ConditionSourceV1] = None,
        end: Optional[Value] = None,
        filter: Optional[Filter] = None,
        include_asset_column: Optional[bool] = True,
        limit: Optional[int] = 40,
        start: Optional[Value] = None,
    ) -> None: ...

    @property
    def capsule_properties(self) -> Optional[List[str]]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: Optional[List[str]]) -> None: ...

    @property
    def condition_properties(self) -> Optional[List[str]]: ...

    @condition_properties.setter
    def condition_properties(self, condition_properties: Optional[List[str]]) -> None: ...

    @property
    def condition_source(self) -> ConditionSourceV1: ...

    @condition_source.setter
    def condition_source(self, condition_source: ConditionSourceV1) -> None: ...

    @property
    def end(self) -> Value: ...

    @end.setter
    def end(self, end: Value) -> None: ...

    @property
    def filter(self) -> Optional[Filter]: ...

    @filter.setter
    def filter(self, filter: Optional[Filter]) -> None: ...

    @property
    def include_asset_column(self) -> Optional[bool]: ...

    @include_asset_column.setter
    def include_asset_column(self, include_asset_column: Optional[bool]) -> None: ...

    @property
    def limit(self) -> int: ...

    @limit.setter
    def limit(self, limit: int) -> None: ...

    @property
    def start(self) -> Value: ...

    @start.setter
    def start(self, start: Value) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
