# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ColumnRuleFindDescendantInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_index: int
    _item_types: Optional[List[str]]
    _property_match_operators: List[str]
    _property_names: List[str]
    _property_value_types: Optional[List[str]]
    _property_value_uoms: Optional[List[str]]
    _property_values: List[str]


    def __init__(
        self,
        column_index: Optional[int] = None,
        item_types: Optional[List[str]] = None,
        property_match_operators: Optional[List[str]] = None,
        property_names: Optional[List[str]] = None,
        property_value_types: Optional[List[str]] = None,
        property_value_uoms: Optional[List[str]] = None,
        property_values: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def column_index(self) -> int: ...

    @column_index.setter
    def column_index(self, column_index: int) -> None: ...

    @property
    def item_types(self) -> Optional[List[str]]: ...

    @item_types.setter
    def item_types(self, item_types: Optional[List[str]]) -> None: ...

    @property
    def property_match_operators(self) -> List[str]: ...

    @property_match_operators.setter
    def property_match_operators(self, property_match_operators: List[str]) -> None: ...

    @property
    def property_names(self) -> List[str]: ...

    @property_names.setter
    def property_names(self, property_names: List[str]) -> None: ...

    @property
    def property_value_types(self) -> Optional[List[str]]: ...

    @property_value_types.setter
    def property_value_types(self, property_value_types: Optional[List[str]]) -> None: ...

    @property
    def property_value_uoms(self) -> Optional[List[str]]: ...

    @property_value_uoms.setter
    def property_value_uoms(self, property_value_uoms: Optional[List[str]]) -> None: ...

    @property
    def property_values(self) -> List[str]: ...

    @property_values.setter
    def property_values(self, property_values: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
