# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ConditionsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_capsules(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def add_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_condition(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def condition_table(
        self,
        **kwargs: Any,
    ) -> TableResultOutputV1: ...

    def condition_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def create_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_capsules(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_capsules(
        self,
        **kwargs: Any,
    ) -> CapsulesOutputV1: ...

    def get_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def get_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_conditions(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_capsules(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def put_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_conditions(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def put_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_existing_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def update_existing_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
