# coding: utf-8
"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, Iterable, List, Optional, Sequence, Tuple, Union

from .configuration import ClientConfiguration


class ApiClient(object):
    configuration: ClientConfiguration
    host: str
    cookie: Optional[str]
    default_headers: Dict[str, Any]
    auth_token: Optional[str]
    identity_path: Optional[str]
    csrf_token: Optional[str]

    def __init__(
        self,
        host: Optional[str] = None,
        header_name: Optional[str] = None,
        header_value: Optional[str] = None,
        cookie: Optional[str] = None,
        configuration: Optional[ClientConfiguration] = None,
    ) -> None: ...

    def set_default_header(self, header_name: str, header_value: str) -> None: ...

    def call_api(
        self,
        resource_path: str,
        method: str,
        path_params: Optional[Dict[str, Any]] = None,
        query_params: Optional[List[Tuple[str, Any]]] = None,
        header_params: Optional[Dict[str, Any]] = None,
        body: Any = None,
        post_params: Any = None,
        files: Any = None,
        response_type: Optional[str] = None,
        auth_settings: Optional[Sequence[str]] = None,
        callback: Any = None,
        _return_http_data_only: Optional[bool] = None,
        _preload_content: bool = True,
        _request_timeout: Any = None,
        collection_formats: Optional[Dict[str, str]] = None,
    ) -> Any: ...

    def sanitize_for_serialization(self, obj: Any) -> Any: ...
    def deserialize(self, response_data: Any, response_type: Any) -> Any: ...

    def parameters_to_tuples(self, params: Any, collection_formats: Optional[Dict[str, str]] = None) -> List[Tuple[str, Any]]: ...

    def select_header_accept(self, accepts: Sequence[str]) -> Optional[str]: ...
    def select_header_content_type(self, content_types: Sequence[str]) -> str: ...

    def add_authorization_header(self, request_headers: Dict[str, Any]) -> None: ...
