# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RemoteAgentStatusInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _available_versions: List[str]
    _base_version: str
    _current_version: str
    _free_disk_space: int
    _pending_progress: Optional[float]
    _pending_status: Optional[str]
    _pending_version: Optional[str]
    _platform: str
    _platform_architecture: str
    _platform_version: str
    _status: Optional[str]
    _updates_enabled: bool


    def __init__(
        self,
        available_versions: Optional[List[str]] = None,
        base_version: Optional[str] = None,
        current_version: Optional[str] = None,
        free_disk_space: Optional[int] = None,
        pending_progress: Optional[float] = None,
        pending_status: Optional[str] = None,
        pending_version: Optional[str] = None,
        platform: Optional[str] = None,
        platform_architecture: Optional[str] = None,
        platform_version: Optional[str] = None,
        status: Optional[str] = None,
        updates_enabled: Optional[bool] = False,
    ) -> None: ...

    @property
    def available_versions(self) -> List[str]: ...

    @available_versions.setter
    def available_versions(self, available_versions: List[str]) -> None: ...

    @property
    def base_version(self) -> str: ...

    @base_version.setter
    def base_version(self, base_version: str) -> None: ...

    @property
    def current_version(self) -> str: ...

    @current_version.setter
    def current_version(self, current_version: str) -> None: ...

    @property
    def free_disk_space(self) -> int: ...

    @free_disk_space.setter
    def free_disk_space(self, free_disk_space: int) -> None: ...

    @property
    def pending_progress(self) -> Optional[float]: ...

    @pending_progress.setter
    def pending_progress(self, pending_progress: Optional[float]) -> None: ...

    @property
    def pending_status(self) -> Optional[str]: ...

    @pending_status.setter
    def pending_status(self, pending_status: Optional[str]) -> None: ...

    @property
    def pending_version(self) -> Optional[str]: ...

    @pending_version.setter
    def pending_version(self, pending_version: Optional[str]) -> None: ...

    @property
    def platform(self) -> str: ...

    @platform.setter
    def platform(self, platform: str) -> None: ...

    @property
    def platform_architecture(self) -> str: ...

    @platform_architecture.setter
    def platform_architecture(self, platform_architecture: str) -> None: ...

    @property
    def platform_version(self) -> str: ...

    @platform_version.setter
    def platform_version(self, platform_version: str) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def updates_enabled(self) -> bool: ...

    @updates_enabled.setter
    def updates_enabled(self, updates_enabled: bool) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
