# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContextNumericOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _archived: bool
    _archived_at: Optional[str]
    _archiver_id: Optional[str]
    _context: str
    _context_id: str
    _created_at: str
    _created_by: Optional[ContextUser]
    _creator_id: str
    _datum_id: Optional[str]
    _end_time: Optional[str]
    _item: Optional[ContextItem]
    _item_id: str
    _numeric_description_id: Optional[str]
    _numeric_description_name: Optional[str]
    _source: Optional[ContextSourceOutputV1]
    _start_time: Optional[str]
    _updated_at: Optional[str]
    _value: Optional[float]


    def __init__(
        self,
        archived: Optional[bool] = None,
        archived_at: Optional[str] = None,
        archiver_id: Optional[str] = None,
        context: Optional[str] = None,
        context_id: Optional[str] = None,
        created_at: Optional[str] = None,
        created_by: Optional[ContextUser] = None,
        creator_id: Optional[str] = None,
        datum_id: Optional[str] = None,
        end_time: Optional[str] = None,
        item: Optional[ContextItem] = None,
        item_id: Optional[str] = None,
        numeric_description_id: Optional[str] = None,
        numeric_description_name: Optional[str] = None,
        source: Optional[ContextSourceOutputV1] = None,
        start_time: Optional[str] = None,
        updated_at: Optional[str] = None,
        value: Optional[float] = None,
    ) -> None: ...

    @property
    def archived(self) -> bool: ...

    @archived.setter
    def archived(self, archived: bool) -> None: ...

    @property
    def archived_at(self) -> Optional[str]: ...

    @archived_at.setter
    def archived_at(self, archived_at: Optional[str]) -> None: ...

    @property
    def archiver_id(self) -> Optional[str]: ...

    @archiver_id.setter
    def archiver_id(self, archiver_id: Optional[str]) -> None: ...

    @property
    def context(self) -> str: ...

    @context.setter
    def context(self, context: str) -> None: ...

    @property
    def context_id(self) -> str: ...

    @context_id.setter
    def context_id(self, context_id: str) -> None: ...

    @property
    def created_at(self) -> str: ...

    @created_at.setter
    def created_at(self, created_at: str) -> None: ...

    @property
    def created_by(self) -> Optional[ContextUser]: ...

    @created_by.setter
    def created_by(self, created_by: Optional[ContextUser]) -> None: ...

    @property
    def creator_id(self) -> str: ...

    @creator_id.setter
    def creator_id(self, creator_id: str) -> None: ...

    @property
    def datum_id(self) -> Optional[str]: ...

    @datum_id.setter
    def datum_id(self, datum_id: Optional[str]) -> None: ...

    @property
    def end_time(self) -> Optional[str]: ...

    @end_time.setter
    def end_time(self, end_time: Optional[str]) -> None: ...

    @property
    def item(self) -> Optional[ContextItem]: ...

    @item.setter
    def item(self, item: Optional[ContextItem]) -> None: ...

    @property
    def item_id(self) -> str: ...

    @item_id.setter
    def item_id(self, item_id: str) -> None: ...

    @property
    def numeric_description_id(self) -> Optional[str]: ...

    @numeric_description_id.setter
    def numeric_description_id(self, numeric_description_id: Optional[str]) -> None: ...

    @property
    def numeric_description_name(self) -> Optional[str]: ...

    @numeric_description_name.setter
    def numeric_description_name(self, numeric_description_name: Optional[str]) -> None: ...

    @property
    def source(self) -> Optional[ContextSourceOutputV1]: ...

    @source.setter
    def source(self, source: Optional[ContextSourceOutputV1]) -> None: ...

    @property
    def start_time(self) -> Optional[str]: ...

    @start_time.setter
    def start_time(self, start_time: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    @property
    def value(self) -> Optional[float]: ...

    @value.setter
    def value(self, value: Optional[float]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
