# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SyncProgress(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_count: Optional[int]
    _asset_progress: Optional[int]
    _condition_count: Optional[int]
    _condition_progress: Optional[int]
    _relationship_count: Optional[int]
    _relationship_progress: Optional[int]
    _scalar_count: Optional[int]
    _scalar_progress: Optional[int]
    _signal_count: Optional[int]
    _signal_progress: Optional[int]
    _user_group_count: Optional[int]
    _user_group_progress: Optional[int]


    def __init__(
        self,
        asset_count: Optional[int] = None,
        asset_progress: Optional[int] = None,
        condition_count: Optional[int] = None,
        condition_progress: Optional[int] = None,
        relationship_count: Optional[int] = None,
        relationship_progress: Optional[int] = None,
        scalar_count: Optional[int] = None,
        scalar_progress: Optional[int] = None,
        signal_count: Optional[int] = None,
        signal_progress: Optional[int] = None,
        user_group_count: Optional[int] = None,
        user_group_progress: Optional[int] = None,
    ) -> None: ...

    @property
    def asset_count(self) -> Optional[int]: ...

    @asset_count.setter
    def asset_count(self, asset_count: Optional[int]) -> None: ...

    @property
    def asset_progress(self) -> Optional[int]: ...

    @asset_progress.setter
    def asset_progress(self, asset_progress: Optional[int]) -> None: ...

    @property
    def condition_count(self) -> Optional[int]: ...

    @condition_count.setter
    def condition_count(self, condition_count: Optional[int]) -> None: ...

    @property
    def condition_progress(self) -> Optional[int]: ...

    @condition_progress.setter
    def condition_progress(self, condition_progress: Optional[int]) -> None: ...

    @property
    def relationship_count(self) -> Optional[int]: ...

    @relationship_count.setter
    def relationship_count(self, relationship_count: Optional[int]) -> None: ...

    @property
    def relationship_progress(self) -> Optional[int]: ...

    @relationship_progress.setter
    def relationship_progress(self, relationship_progress: Optional[int]) -> None: ...

    @property
    def scalar_count(self) -> Optional[int]: ...

    @scalar_count.setter
    def scalar_count(self, scalar_count: Optional[int]) -> None: ...

    @property
    def scalar_progress(self) -> Optional[int]: ...

    @scalar_progress.setter
    def scalar_progress(self, scalar_progress: Optional[int]) -> None: ...

    @property
    def signal_count(self) -> Optional[int]: ...

    @signal_count.setter
    def signal_count(self, signal_count: Optional[int]) -> None: ...

    @property
    def signal_progress(self) -> Optional[int]: ...

    @signal_progress.setter
    def signal_progress(self, signal_progress: Optional[int]) -> None: ...

    @property
    def user_group_count(self) -> Optional[int]: ...

    @user_group_count.setter
    def user_group_count(self, user_group_count: Optional[int]) -> None: ...

    @property
    def user_group_progress(self) -> Optional[int]: ...

    @user_group_progress.setter
    def user_group_progress(self, user_group_progress: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
