# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MonitoredSignalLastRunStateOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cursor_key: Optional[int]
    _error_count: Optional[int]
    _last_certain_sample: Optional[SampleOutputV1]
    _last_error: Optional[str]
    _last_error_time_created: Optional[int]
    _signal_guid: str
    _uncertain_samples: Optional[List[SampleOutputV1]]


    def __init__(
        self,
        cursor_key: Optional[int] = None,
        error_count: Optional[int] = None,
        last_certain_sample: Optional[SampleOutputV1] = None,
        last_error: Optional[str] = None,
        last_error_time_created: Optional[int] = None,
        signal_guid: Optional[str] = None,
        uncertain_samples: Optional[List[SampleOutputV1]] = None,
    ) -> None: ...

    @property
    def cursor_key(self) -> Optional[int]: ...

    @cursor_key.setter
    def cursor_key(self, cursor_key: Optional[int]) -> None: ...

    @property
    def error_count(self) -> Optional[int]: ...

    @error_count.setter
    def error_count(self, error_count: Optional[int]) -> None: ...

    @property
    def last_certain_sample(self) -> Optional[SampleOutputV1]: ...

    @last_certain_sample.setter
    def last_certain_sample(self, last_certain_sample: Optional[SampleOutputV1]) -> None: ...

    @property
    def last_error(self) -> Optional[str]: ...

    @last_error.setter
    def last_error(self, last_error: Optional[str]) -> None: ...

    @property
    def last_error_time_created(self) -> Optional[int]: ...

    @last_error_time_created.setter
    def last_error_time_created(self, last_error_time_created: Optional[int]) -> None: ...

    @property
    def signal_guid(self) -> str: ...

    @signal_guid.setter
    def signal_guid(self, signal_guid: str) -> None: ...

    @property
    def uncertain_samples(self) -> Optional[List[SampleOutputV1]]: ...

    @uncertain_samples.setter
    def uncertain_samples(self, uncertain_samples: Optional[List[SampleOutputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
