# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ContextApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def batch_archive_context_labels(
        self,
        **kwargs: Any,
    ) -> None: ...

    def batch_archive_context_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def batch_create_context_labels(
        self,
        **kwargs: Any,
    ) -> List[ContextLabelOutputV1]: ...

    def batch_create_context_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_comment_category(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputV1: ...

    def create_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_comment(
        self,
        **kwargs: Any,
    ) -> ContextCommentOutputV1: ...

    def create_context_comment_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_label(
        self,
        **kwargs: Any,
    ) -> ContextLabelOutputV1: ...

    def create_context_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_numeric(
        self,
        **kwargs: Any,
    ) -> ContextNumericOutputV1: ...

    def create_context_numeric_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_opaque(
        self,
        **kwargs: Any,
    ) -> ContextOpaqueOutputV1: ...

    def create_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_label(
        self,
        **kwargs: Any,
    ) -> LabelOutputV1: ...

    def create_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_label_category(
        self,
        **kwargs: Any,
    ) -> LabelCategoryOutputV1: ...

    def create_label_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_numeric_description(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputV1: ...

    def create_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_comment_category(
        self,
        **kwargs: Any,
    ) -> None: ...

    def delete_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_comment(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_context_comment_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_label(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def delete_context_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_numeric(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_context_numeric_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_context_opaque(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_label(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def delete_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_label_category(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def delete_label_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_numeric_description(
        self,
        **kwargs: Any,
    ) -> None: ...

    def delete_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def find_label_categories(
        self,
        **kwargs: Any,
    ) -> LabelCategoryOutputListV1: ...

    def find_label_categories_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def find_labels(
        self,
        **kwargs: Any,
    ) -> LabelOutputListV1: ...

    def find_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_comment_categories(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputListV1: ...

    def get_all_comment_categories_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_context(
        self,
        **kwargs: Any,
    ) -> AllContextOutputV1: ...

    def get_all_context_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_all_numeric_descriptions(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputListV1: ...

    def get_all_numeric_descriptions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_comment_category(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputV1: ...

    def get_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_comments(
        self,
        **kwargs: Any,
    ) -> ContextCommentListOutputV1: ...

    def get_context_comments_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_conditions(
        self,
        **kwargs: Any,
    ) -> ContextConditionOutputListV1: ...

    def get_context_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_labels(
        self,
        **kwargs: Any,
    ) -> ContextLabelListOutputV1: ...

    def get_context_labels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_numerics(
        self,
        **kwargs: Any,
    ) -> ContextNumericListOutputV1: ...

    def get_context_numerics_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_opaque(
        self,
        **kwargs: Any,
    ) -> ContextOpaqueListOutputV1: ...

    def get_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_label_hierarchies(
        self,
        **kwargs: Any,
    ) -> LabelHierarchyOutputListV1: ...

    def get_label_hierarchies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_labeled_items(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_labeled_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_numeric_description(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputV1: ...

    def get_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_numeric_description_with_path_id(
        self,
        **kwargs: Any,
    ) -> NumericDescriptionOutputV1: ...

    def get_numeric_description_with_path_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_comment_category(
        self,
        **kwargs: Any,
    ) -> CommentCategoryOutputV1: ...

    def update_comment_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_context_comment(
        self,
        **kwargs: Any,
    ) -> ContextCommentOutputV1: ...

    def update_context_comment_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_context_numeric(
        self,
        **kwargs: Any,
    ) -> ContextNumericOutputV1: ...

    def update_context_numeric_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_context_opaque(
        self,
        **kwargs: Any,
    ) -> ContextOpaqueOutputV1: ...

    def update_context_opaque_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_label(
        self,
        **kwargs: Any,
    ) -> LabelOutputV1: ...

    def update_label_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_label_category(
        self,
        **kwargs: Any,
    ) -> LabelCategoryOutputV1: ...

    def update_label_category_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_numeric_description(
        self,
        **kwargs: Any,
    ) -> ContextNumericOutputV1: ...

    def update_numeric_description_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
