# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class CustomAgentsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_custom_agent(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def create_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_custom_agent_draft(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def create_custom_agent_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_custom_agent_version(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentVersionOutputV1]: ...

    def create_custom_agent_version_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def discard_custom_agent_draft(
        self,
        **kwargs: Any,
    ) -> None: ...

    def discard_custom_agent_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def duplicate_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def duplicate_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def get_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent_draft_working_copies(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentDraftOutputV1]: ...

    def get_custom_agent_draft_working_copies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent_version_graph(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def get_custom_agent_version_graph_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agent_versions(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentVersionOutputV1]: ...

    def get_custom_agent_versions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_custom_agents(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentSummaryOutputV1]: ...

    def get_custom_agents_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def revert_custom_agent_to_version(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def revert_custom_agent_to_version_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_custom_agent_production(
        self,
        **kwargs: Any,
    ) -> List[CustomAgentVersionOutputV1]: ...

    def set_custom_agent_production_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_custom_agent(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def update_custom_agent_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_custom_agent_draft(
        self,
        **kwargs: Any,
    ) -> CustomAgentOutputV1: ...

    def update_custom_agent_draft_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
