# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemFinderInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cron_schedule: Optional[List[str]]
    _description: Optional[str]
    _enabled: Optional[bool]
    _fixed_list_searches: Optional[List[FixedListSearchV1]]
    _hierarchy_searches: Optional[List[HierarchySearchV1]]
    _include_hierarchy: Optional[bool]
    _name: str
    _property_searches: Optional[List[PropertySearchV1]]
    _scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]]
    _scoped_to: Optional[str]
    _searches: Optional[List[SwapAcrossAssetsSearchV1]]
    _skip_job_scheduling: Optional[bool]
    _stored_table_searches: Optional[List[StoredTableSearchV1]]
    _timezone: Optional[str]


    def __init__(
        self,
        cron_schedule: Optional[List[str]] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        fixed_list_searches: Optional[List[FixedListSearchV1]] = None,
        hierarchy_searches: Optional[List[HierarchySearchV1]] = None,
        include_hierarchy: Optional[bool] = False,
        name: Optional[str] = None,
        property_searches: Optional[List[PropertySearchV1]] = None,
        scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]] = None,
        scoped_to: Optional[str] = None,
        searches: Optional[List[SwapAcrossAssetsSearchV1]] = None,
        skip_job_scheduling: Optional[bool] = False,
        stored_table_searches: Optional[List[StoredTableSearchV1]] = None,
        timezone: Optional[str] = None,
    ) -> None: ...

    @property
    def cron_schedule(self) -> Optional[List[str]]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: Optional[List[str]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def fixed_list_searches(self) -> Optional[List[FixedListSearchV1]]: ...

    @fixed_list_searches.setter
    def fixed_list_searches(self, fixed_list_searches: Optional[List[FixedListSearchV1]]) -> None: ...

    @property
    def hierarchy_searches(self) -> Optional[List[HierarchySearchV1]]: ...

    @hierarchy_searches.setter
    def hierarchy_searches(self, hierarchy_searches: Optional[List[HierarchySearchV1]]) -> None: ...

    @property
    def include_hierarchy(self) -> Optional[bool]: ...

    @include_hierarchy.setter
    def include_hierarchy(self, include_hierarchy: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def property_searches(self) -> Optional[List[PropertySearchV1]]: ...

    @property_searches.setter
    def property_searches(self, property_searches: Optional[List[PropertySearchV1]]) -> None: ...

    @property
    def scaling_table_uuid_column_searches(self) -> Optional[List[ScalingTableUUIDColumnSearchV1]]: ...

    @scaling_table_uuid_column_searches.setter
    def scaling_table_uuid_column_searches(self, scaling_table_uuid_column_searches: Optional[List[ScalingTableUUIDColumnSearchV1]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def searches(self) -> Optional[List[SwapAcrossAssetsSearchV1]]: ...

    @searches.setter
    def searches(self, searches: Optional[List[SwapAcrossAssetsSearchV1]]) -> None: ...

    @property
    def skip_job_scheduling(self) -> Optional[bool]: ...

    @skip_job_scheduling.setter
    def skip_job_scheduling(self, skip_job_scheduling: Optional[bool]) -> None: ...

    @property
    def stored_table_searches(self) -> Optional[List[StoredTableSearchV1]]: ...

    @stored_table_searches.setter
    def stored_table_searches(self, stored_table_searches: Optional[List[StoredTableSearchV1]]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
