# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_config_json: Optional[str]
    _agent_name: Optional[str]
    _backups: Optional[List[JsonBackupOutputV1]]
    _configured_fields_json: Optional[str]
    _connection_id: Optional[str]
    _connector_name: Optional[str]
    _created_at: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: Optional[bool]
    _field_configurations: Optional[List[ConfigFieldV1]]
    _id: str
    _indexing_connection: Optional[bool]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _json: Optional[str]
    _max_concurrent_requests: Optional[int]
    _max_results_per_requests: Optional[int]
    _name: str
    _propagation_pending: Optional[bool]
    _pull_connection: Optional[bool]
    _status_message: Optional[str]
    _transforms: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        additional_config_json: Optional[str] = None,
        agent_name: Optional[str] = None,
        backups: Optional[List[JsonBackupOutputV1]] = None,
        configured_fields_json: Optional[str] = None,
        connection_id: Optional[str] = None,
        connector_name: Optional[str] = None,
        created_at: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = False,
        field_configurations: Optional[List[ConfigFieldV1]] = None,
        id: Optional[str] = None,
        indexing_connection: Optional[bool] = False,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        json: Optional[str] = None,
        max_concurrent_requests: Optional[int] = None,
        max_results_per_requests: Optional[int] = None,
        name: Optional[str] = None,
        propagation_pending: Optional[bool] = False,
        pull_connection: Optional[bool] = False,
        status_message: Optional[str] = None,
        transforms: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_config_json(self) -> Optional[str]: ...

    @additional_config_json.setter
    def additional_config_json(self, additional_config_json: Optional[str]) -> None: ...

    @property
    def agent_name(self) -> Optional[str]: ...

    @agent_name.setter
    def agent_name(self, agent_name: Optional[str]) -> None: ...

    @property
    def backups(self) -> Optional[List[JsonBackupOutputV1]]: ...

    @backups.setter
    def backups(self, backups: Optional[List[JsonBackupOutputV1]]) -> None: ...

    @property
    def configured_fields_json(self) -> Optional[str]: ...

    @configured_fields_json.setter
    def configured_fields_json(self, configured_fields_json: Optional[str]) -> None: ...

    @property
    def connection_id(self) -> Optional[str]: ...

    @connection_id.setter
    def connection_id(self, connection_id: Optional[str]) -> None: ...

    @property
    def connector_name(self) -> Optional[str]: ...

    @connector_name.setter
    def connector_name(self, connector_name: Optional[str]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def field_configurations(self) -> Optional[List[ConfigFieldV1]]: ...

    @field_configurations.setter
    def field_configurations(self, field_configurations: Optional[List[ConfigFieldV1]]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def indexing_connection(self) -> Optional[bool]: ...

    @indexing_connection.setter
    def indexing_connection(self, indexing_connection: Optional[bool]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def json(self) -> Optional[str]: ...

    @json.setter
    def json(self, json: Optional[str]) -> None: ...

    @property
    def max_concurrent_requests(self) -> Optional[int]: ...

    @max_concurrent_requests.setter
    def max_concurrent_requests(self, max_concurrent_requests: Optional[int]) -> None: ...

    @property
    def max_results_per_requests(self) -> Optional[int]: ...

    @max_results_per_requests.setter
    def max_results_per_requests(self, max_results_per_requests: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def propagation_pending(self) -> Optional[bool]: ...

    @propagation_pending.setter
    def propagation_pending(self, propagation_pending: Optional[bool]) -> None: ...

    @property
    def pull_connection(self) -> Optional[bool]: ...

    @pull_connection.setter
    def pull_connection(self, pull_connection: Optional[bool]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def transforms(self) -> Optional[str]: ...

    @transforms.setter
    def transforms(self, transforms: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
