# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'absolute_threshold': 'float',
        'applied_filters': 'list[BoardFilterInputV1]',
        'baseline_end': 'str',
        'baseline_start': 'str',
        'current_end': 'str',
        'current_start': 'str',
        'limit': 'int',
        'metric': 'str',
        'percent_threshold': 'float',
        'tile_ids': 'list[str]'
    }

    attribute_map = {
        'absolute_threshold': 'absoluteThreshold',
        'applied_filters': 'appliedFilters',
        'baseline_end': 'baselineEnd',
        'baseline_start': 'baselineStart',
        'current_end': 'currentEnd',
        'current_start': 'currentStart',
        'limit': 'limit',
        'metric': 'metric',
        'percent_threshold': 'percentThreshold',
        'tile_ids': 'tileIds'
    }

    def __init__(self, absolute_threshold=None, applied_filters=None, baseline_end=None, baseline_start=None, current_end=None, current_start=None, limit=None, metric=None, percent_threshold=None, tile_ids=None):
        """
        BoardTimeframeComparisonInputV1 - a model defined in Swagger
        """

        self._absolute_threshold = None
        self._applied_filters = None
        self._baseline_end = None
        self._baseline_start = None
        self._current_end = None
        self._current_start = None
        self._limit = None
        self._metric = None
        self._percent_threshold = None
        self._tile_ids = None

        if absolute_threshold is not None:
          self.absolute_threshold = absolute_threshold
        if applied_filters is not None:
          self.applied_filters = applied_filters
        if baseline_end is not None:
          self.baseline_end = baseline_end
        if baseline_start is not None:
          self.baseline_start = baseline_start
        if current_end is not None:
          self.current_end = current_end
        if current_start is not None:
          self.current_start = current_start
        if limit is not None:
          self.limit = limit
        if metric is not None:
          self.metric = metric
        if percent_threshold is not None:
          self.percent_threshold = percent_threshold
        if tile_ids is not None:
          self.tile_ids = tile_ids

    @property
    def absolute_threshold(self):
        """
        Gets the absolute_threshold of this BoardTimeframeComparisonInputV1.
        Absolute change threshold when baseline is zero

        :return: The absolute_threshold of this BoardTimeframeComparisonInputV1.
        :rtype: float
        """
        return self._absolute_threshold

    @absolute_threshold.setter
    def absolute_threshold(self, absolute_threshold):
        """
        Sets the absolute_threshold of this BoardTimeframeComparisonInputV1.
        Absolute change threshold when baseline is zero

        :param absolute_threshold: The absolute_threshold of this BoardTimeframeComparisonInputV1.
        :type: float
        """

        self._absolute_threshold = absolute_threshold

    @property
    def applied_filters(self):
        """
        Gets the applied_filters of this BoardTimeframeComparisonInputV1.
        Filters to apply to the board data

        :return: The applied_filters of this BoardTimeframeComparisonInputV1.
        :rtype: list[BoardFilterInputV1]
        """
        return self._applied_filters

    @applied_filters.setter
    def applied_filters(self, applied_filters):
        """
        Sets the applied_filters of this BoardTimeframeComparisonInputV1.
        Filters to apply to the board data

        :param applied_filters: The applied_filters of this BoardTimeframeComparisonInputV1.
        :type: list[BoardFilterInputV1]
        """

        self._applied_filters = applied_filters

    @property
    def baseline_end(self):
        """
        Gets the baseline_end of this BoardTimeframeComparisonInputV1.
        Baseline range end (ISO-8601)

        :return: The baseline_end of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._baseline_end

    @baseline_end.setter
    def baseline_end(self, baseline_end):
        """
        Sets the baseline_end of this BoardTimeframeComparisonInputV1.
        Baseline range end (ISO-8601)

        :param baseline_end: The baseline_end of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if baseline_end is None:
            raise ValueError("Invalid value for `baseline_end`, must not be `None`")

        self._baseline_end = baseline_end

    @property
    def baseline_start(self):
        """
        Gets the baseline_start of this BoardTimeframeComparisonInputV1.
        Baseline range start (ISO-8601)

        :return: The baseline_start of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._baseline_start

    @baseline_start.setter
    def baseline_start(self, baseline_start):
        """
        Sets the baseline_start of this BoardTimeframeComparisonInputV1.
        Baseline range start (ISO-8601)

        :param baseline_start: The baseline_start of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if baseline_start is None:
            raise ValueError("Invalid value for `baseline_start`, must not be `None`")

        self._baseline_start = baseline_start

    @property
    def current_end(self):
        """
        Gets the current_end of this BoardTimeframeComparisonInputV1.
        Current range end (ISO-8601)

        :return: The current_end of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._current_end

    @current_end.setter
    def current_end(self, current_end):
        """
        Sets the current_end of this BoardTimeframeComparisonInputV1.
        Current range end (ISO-8601)

        :param current_end: The current_end of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if current_end is None:
            raise ValueError("Invalid value for `current_end`, must not be `None`")

        self._current_end = current_end

    @property
    def current_start(self):
        """
        Gets the current_start of this BoardTimeframeComparisonInputV1.
        Current range start (ISO-8601)

        :return: The current_start of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._current_start

    @current_start.setter
    def current_start(self, current_start):
        """
        Sets the current_start of this BoardTimeframeComparisonInputV1.
        Current range start (ISO-8601)

        :param current_start: The current_start of this BoardTimeframeComparisonInputV1.
        :type: str
        """
        if current_start is None:
            raise ValueError("Invalid value for `current_start`, must not be `None`")

        self._current_start = current_start

    @property
    def limit(self):
        """
        Gets the limit of this BoardTimeframeComparisonInputV1.
        Maximum number of rows to fetch

        :return: The limit of this BoardTimeframeComparisonInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this BoardTimeframeComparisonInputV1.
        Maximum number of rows to fetch

        :param limit: The limit of this BoardTimeframeComparisonInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def metric(self):
        """
        Gets the metric of this BoardTimeframeComparisonInputV1.
        Metric to compare: mean|sum|min|max

        :return: The metric of this BoardTimeframeComparisonInputV1.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this BoardTimeframeComparisonInputV1.
        Metric to compare: mean|sum|min|max

        :param metric: The metric of this BoardTimeframeComparisonInputV1.
        :type: str
        """

        self._metric = metric

    @property
    def percent_threshold(self):
        """
        Gets the percent_threshold of this BoardTimeframeComparisonInputV1.
        Percent change threshold for reporting

        :return: The percent_threshold of this BoardTimeframeComparisonInputV1.
        :rtype: float
        """
        return self._percent_threshold

    @percent_threshold.setter
    def percent_threshold(self, percent_threshold):
        """
        Sets the percent_threshold of this BoardTimeframeComparisonInputV1.
        Percent change threshold for reporting

        :param percent_threshold: The percent_threshold of this BoardTimeframeComparisonInputV1.
        :type: float
        """

        self._percent_threshold = percent_threshold

    @property
    def tile_ids(self):
        """
        Gets the tile_ids of this BoardTimeframeComparisonInputV1.
        Optional list of tile IDs to compare

        :return: The tile_ids of this BoardTimeframeComparisonInputV1.
        :rtype: list[str]
        """
        return self._tile_ids

    @tile_ids.setter
    def tile_ids(self, tile_ids):
        """
        Sets the tile_ids of this BoardTimeframeComparisonInputV1.
        Optional list of tile IDs to compare

        :param tile_ids: The tile_ids of this BoardTimeframeComparisonInputV1.
        :type: list[str]
        """

        self._tile_ids = tile_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
