# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RequestOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _activities: Optional[List[ActivityOutputV1]]
    _activity_graph: Optional[ActivityGraphOutputV1]
    _detailed_meters: Optional[List[DetailedMeterOutputV1]]
    _detailed_timers: Optional[List[DetailedTimerOutputV1]]
    _flame_graph: Optional[FoldedStackNodeV1]
    _href: str
    _parallelization_count: int
    _parameters: Optional[Dict[str, List[str]]]
    _progress: Optional[ProgressInformationOutputV1]
    _request_method: str
    _request_path: str
    _run_duration: int
    _user_email: str
    _username: str


    def __init__(
        self,
        activities: Optional[List[ActivityOutputV1]] = None,
        activity_graph: Optional[ActivityGraphOutputV1] = None,
        detailed_meters: Optional[List[DetailedMeterOutputV1]] = None,
        detailed_timers: Optional[List[DetailedTimerOutputV1]] = None,
        flame_graph: Optional[FoldedStackNodeV1] = None,
        href: Optional[str] = None,
        parallelization_count: Optional[int] = None,
        parameters: Optional[Dict[str, List[str]]] = None,
        progress: Optional[ProgressInformationOutputV1] = None,
        request_method: Optional[str] = None,
        request_path: Optional[str] = None,
        run_duration: Optional[int] = None,
        user_email: Optional[str] = None,
        username: Optional[str] = None,
    ) -> None: ...

    @property
    def activities(self) -> Optional[List[ActivityOutputV1]]: ...

    @activities.setter
    def activities(self, activities: Optional[List[ActivityOutputV1]]) -> None: ...

    @property
    def activity_graph(self) -> Optional[ActivityGraphOutputV1]: ...

    @activity_graph.setter
    def activity_graph(self, activity_graph: Optional[ActivityGraphOutputV1]) -> None: ...

    @property
    def detailed_meters(self) -> Optional[List[DetailedMeterOutputV1]]: ...

    @detailed_meters.setter
    def detailed_meters(self, detailed_meters: Optional[List[DetailedMeterOutputV1]]) -> None: ...

    @property
    def detailed_timers(self) -> Optional[List[DetailedTimerOutputV1]]: ...

    @detailed_timers.setter
    def detailed_timers(self, detailed_timers: Optional[List[DetailedTimerOutputV1]]) -> None: ...

    @property
    def flame_graph(self) -> Optional[FoldedStackNodeV1]: ...

    @flame_graph.setter
    def flame_graph(self, flame_graph: Optional[FoldedStackNodeV1]) -> None: ...

    @property
    def href(self) -> str: ...

    @href.setter
    def href(self, href: str) -> None: ...

    @property
    def parallelization_count(self) -> int: ...

    @parallelization_count.setter
    def parallelization_count(self, parallelization_count: int) -> None: ...

    @property
    def parameters(self) -> Optional[Dict[str, List[str]]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[Dict[str, List[str]]]) -> None: ...

    @property
    def progress(self) -> Optional[ProgressInformationOutputV1]: ...

    @progress.setter
    def progress(self, progress: Optional[ProgressInformationOutputV1]) -> None: ...

    @property
    def request_method(self) -> str: ...

    @request_method.setter
    def request_method(self, request_method: str) -> None: ...

    @property
    def request_path(self) -> str: ...

    @request_path.setter
    def request_path(self, request_path: str) -> None: ...

    @property
    def run_duration(self) -> int: ...

    @run_duration.setter
    def run_duration(self, run_duration: int) -> None: ...

    @property
    def user_email(self) -> str: ...

    @user_email.setter
    def user_email(self, user_email: str) -> None: ...

    @property
    def username(self) -> str: ...

    @username.setter
    def username(self, username: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
