# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CacheBlock(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _authoritative_region: Optional[AuthoritativeRegionOutputV1]
    _blob_id: Optional[int]
    _capsules: Optional[List[CapsuleV1]]
    _creation_time: Optional[str]
    _cursor: Optional[str]
    _last_access_time: Optional[str]
    _length_in_bytes: Optional[int]
    _length_in_datums: Optional[int]
    _record_id: Optional[int]
    _samples: Optional[List[SampleOutputV1]]
    _series_id: Optional[str]
    _ttl: Optional[int]


    def __init__(
        self,
        authoritative_region: Optional[AuthoritativeRegionOutputV1] = None,
        blob_id: Optional[int] = None,
        capsules: Optional[List[CapsuleV1]] = None,
        creation_time: Optional[str] = None,
        cursor: Optional[str] = None,
        last_access_time: Optional[str] = None,
        length_in_bytes: Optional[int] = None,
        length_in_datums: Optional[int] = None,
        record_id: Optional[int] = None,
        samples: Optional[List[SampleOutputV1]] = None,
        series_id: Optional[str] = None,
        ttl: Optional[int] = None,
    ) -> None: ...

    @property
    def authoritative_region(self) -> Optional[AuthoritativeRegionOutputV1]: ...

    @authoritative_region.setter
    def authoritative_region(self, authoritative_region: Optional[AuthoritativeRegionOutputV1]) -> None: ...

    @property
    def blob_id(self) -> Optional[int]: ...

    @blob_id.setter
    def blob_id(self, blob_id: Optional[int]) -> None: ...

    @property
    def capsules(self) -> Optional[List[CapsuleV1]]: ...

    @capsules.setter
    def capsules(self, capsules: Optional[List[CapsuleV1]]) -> None: ...

    @property
    def creation_time(self) -> Optional[str]: ...

    @creation_time.setter
    def creation_time(self, creation_time: Optional[str]) -> None: ...

    @property
    def cursor(self) -> Optional[str]: ...

    @cursor.setter
    def cursor(self, cursor: Optional[str]) -> None: ...

    @property
    def last_access_time(self) -> Optional[str]: ...

    @last_access_time.setter
    def last_access_time(self, last_access_time: Optional[str]) -> None: ...

    @property
    def length_in_bytes(self) -> Optional[int]: ...

    @length_in_bytes.setter
    def length_in_bytes(self, length_in_bytes: Optional[int]) -> None: ...

    @property
    def length_in_datums(self) -> Optional[int]: ...

    @length_in_datums.setter
    def length_in_datums(self, length_in_datums: Optional[int]) -> None: ...

    @property
    def record_id(self) -> Optional[int]: ...

    @record_id.setter
    def record_id(self, record_id: Optional[int]) -> None: ...

    @property
    def samples(self) -> Optional[List[SampleOutputV1]]: ...

    @samples.setter
    def samples(self, samples: Optional[List[SampleOutputV1]]) -> None: ...

    @property
    def series_id(self) -> Optional[str]: ...

    @series_id.setter
    def series_id(self, series_id: Optional[str]) -> None: ...

    @property
    def ttl(self) -> Optional[int]: ...

    @ttl.setter
    def ttl(self, ttl: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
