# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContentWithMetadataListOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_selections: Optional[List[AssetSelectionOutputV1]]
    _content_items: Optional[List[ContentWithMetadataOutputV1]]
    _date_ranges: Optional[List[DateRangeOutputV1]]


    def __init__(
        self,
        asset_selections: Optional[List[AssetSelectionOutputV1]] = None,
        content_items: Optional[List[ContentWithMetadataOutputV1]] = None,
        date_ranges: Optional[List[DateRangeOutputV1]] = None,
    ) -> None: ...

    @property
    def asset_selections(self) -> Optional[List[AssetSelectionOutputV1]]: ...

    @asset_selections.setter
    def asset_selections(self, asset_selections: Optional[List[AssetSelectionOutputV1]]) -> None: ...

    @property
    def content_items(self) -> Optional[List[ContentWithMetadataOutputV1]]: ...

    @content_items.setter
    def content_items(self, content_items: Optional[List[ContentWithMetadataOutputV1]]) -> None: ...

    @property
    def date_ranges(self) -> Optional[List[DateRangeOutputV1]]: ...

    @date_ranges.setter
    def date_ranges(self, date_ranges: Optional[List[DateRangeOutputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
