# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FolderSearchResultsV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'estimated_total_hits': 'int',
        'facet_distribution': 'dict(str, object)',
        'hits': 'list[dict(str, object)]',
        'hits_per_page': 'int',
        'page': 'int',
        'path': 'list[ItemPreviewV1]'
    }

    attribute_map = {
        'estimated_total_hits': 'estimatedTotalHits',
        'facet_distribution': 'facetDistribution',
        'hits': 'hits',
        'hits_per_page': 'hitsPerPage',
        'page': 'page',
        'path': 'path'
    }

    def __init__(self, estimated_total_hits=None, facet_distribution=None, hits=None, hits_per_page=None, page=None, path=None):
        """
        FolderSearchResultsV1 - a model defined in Swagger
        """

        self._estimated_total_hits = None
        self._facet_distribution = None
        self._hits = None
        self._hits_per_page = None
        self._page = None
        self._path = None

        if estimated_total_hits is not None:
          self.estimated_total_hits = estimated_total_hits
        if facet_distribution is not None:
          self.facet_distribution = facet_distribution
        if hits is not None:
          self.hits = hits
        if hits_per_page is not None:
          self.hits_per_page = hits_per_page
        if page is not None:
          self.page = page
        if path is not None:
          self.path = path

    @property
    def estimated_total_hits(self):
        """
        Gets the estimated_total_hits of this FolderSearchResultsV1.
        Total number of hits.

        :return: The estimated_total_hits of this FolderSearchResultsV1.
        :rtype: int
        """
        return self._estimated_total_hits

    @estimated_total_hits.setter
    def estimated_total_hits(self, estimated_total_hits):
        """
        Sets the estimated_total_hits of this FolderSearchResultsV1.
        Total number of hits.

        :param estimated_total_hits: The estimated_total_hits of this FolderSearchResultsV1.
        :type: int
        """
        if estimated_total_hits is None:
            raise ValueError("Invalid value for `estimated_total_hits`, must not be `None`")

        self._estimated_total_hits = estimated_total_hits

    @property
    def facet_distribution(self):
        """
        Gets the facet_distribution of this FolderSearchResultsV1.
        A dictionary of facet distributions, where top-level keys are properties and the sub-dictionaries map facet names to counts of matching content.

        :return: The facet_distribution of this FolderSearchResultsV1.
        :rtype: dict(str, object)
        """
        return self._facet_distribution

    @facet_distribution.setter
    def facet_distribution(self, facet_distribution):
        """
        Sets the facet_distribution of this FolderSearchResultsV1.
        A dictionary of facet distributions, where top-level keys are properties and the sub-dictionaries map facet names to counts of matching content.

        :param facet_distribution: The facet_distribution of this FolderSearchResultsV1.
        :type: dict(str, object)
        """
        if facet_distribution is None:
            raise ValueError("Invalid value for `facet_distribution`, must not be `None`")

        self._facet_distribution = facet_distribution

    @property
    def hits(self):
        """
        Gets the hits of this FolderSearchResultsV1.
        List of search result hits. Each list entry contains two keys: 'Content' and 'Formatted', which each contain the unmodified content but the latter contains values formatted for display based on the hitHighlightHtmlTag that was specified in the API call.

        :return: The hits of this FolderSearchResultsV1.
        :rtype: list[dict(str, object)]
        """
        return self._hits

    @hits.setter
    def hits(self, hits):
        """
        Sets the hits of this FolderSearchResultsV1.
        List of search result hits. Each list entry contains two keys: 'Content' and 'Formatted', which each contain the unmodified content but the latter contains values formatted for display based on the hitHighlightHtmlTag that was specified in the API call.

        :param hits: The hits of this FolderSearchResultsV1.
        :type: list[dict(str, object)]
        """
        if hits is None:
            raise ValueError("Invalid value for `hits`, must not be `None`")

        self._hits = hits

    @property
    def hits_per_page(self):
        """
        Gets the hits_per_page of this FolderSearchResultsV1.
        Number of hits that were requested to return per page.

        :return: The hits_per_page of this FolderSearchResultsV1.
        :rtype: int
        """
        return self._hits_per_page

    @hits_per_page.setter
    def hits_per_page(self, hits_per_page):
        """
        Sets the hits_per_page of this FolderSearchResultsV1.
        Number of hits that were requested to return per page.

        :param hits_per_page: The hits_per_page of this FolderSearchResultsV1.
        :type: int
        """
        if hits_per_page is None:
            raise ValueError("Invalid value for `hits_per_page`, must not be `None`")

        self._hits_per_page = hits_per_page

    @property
    def page(self):
        """
        Gets the page of this FolderSearchResultsV1.
        One-based page number that was retrieved. (i.e., 1 is always the first page.) If zero was specified for 'page' in the API call, then no hits are returned -- only the hit counts.

        :return: The page of this FolderSearchResultsV1.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this FolderSearchResultsV1.
        One-based page number that was retrieved. (i.e., 1 is always the first page.) If zero was specified for 'page' in the API call, then no hits are returned -- only the hit counts.

        :param page: The page of this FolderSearchResultsV1.
        :type: int
        """
        if page is None:
            raise ValueError("Invalid value for `page`, must not be `None`")

        self._page = page

    @property
    def path(self):
        """
        Gets the path of this FolderSearchResultsV1.
        The list of folders that specify where this these items are in the folder hierarchy.

        :return: The path of this FolderSearchResultsV1.
        :rtype: list[ItemPreviewV1]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this FolderSearchResultsV1.
        The list of folders that specify where this these items are in the folder hierarchy.

        :param path: The path of this FolderSearchResultsV1.
        :type: list[ItemPreviewV1]
        """

        self._path = path

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FolderSearchResultsV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
