# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTimeframeComparisonTileOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'skip_reason': 'str',
        'skipped': 'bool',
        'tile_id': 'str',
        'tile_name': 'str',
        'tile_type': 'str',
        'variations': 'list[BoardTimeframeComparisonMetricOutputV1]'
    }

    attribute_map = {
        'skip_reason': 'skipReason',
        'skipped': 'skipped',
        'tile_id': 'tileId',
        'tile_name': 'tileName',
        'tile_type': 'tileType',
        'variations': 'variations'
    }

    def __init__(self, skip_reason=None, skipped=None, tile_id=None, tile_name=None, tile_type=None, variations=None):
        """
        BoardTimeframeComparisonTileOutputV1 - a model defined in Swagger
        """

        self._skip_reason = None
        self._skipped = None
        self._tile_id = None
        self._tile_name = None
        self._tile_type = None
        self._variations = None

        if skip_reason is not None:
          self.skip_reason = skip_reason
        if skipped is not None:
          self.skipped = skipped
        if tile_id is not None:
          self.tile_id = tile_id
        if tile_name is not None:
          self.tile_name = tile_name
        if tile_type is not None:
          self.tile_type = tile_type
        if variations is not None:
          self.variations = variations

    @property
    def skip_reason(self):
        """
        Gets the skip_reason of this BoardTimeframeComparisonTileOutputV1.
        Reason the tile was skipped

        :return: The skip_reason of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._skip_reason

    @skip_reason.setter
    def skip_reason(self, skip_reason):
        """
        Sets the skip_reason of this BoardTimeframeComparisonTileOutputV1.
        Reason the tile was skipped

        :param skip_reason: The skip_reason of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """

        self._skip_reason = skip_reason

    @property
    def skipped(self):
        """
        Gets the skipped of this BoardTimeframeComparisonTileOutputV1.
        Whether the tile was skipped

        :return: The skipped of this BoardTimeframeComparisonTileOutputV1.
        :rtype: bool
        """
        return self._skipped

    @skipped.setter
    def skipped(self, skipped):
        """
        Sets the skipped of this BoardTimeframeComparisonTileOutputV1.
        Whether the tile was skipped

        :param skipped: The skipped of this BoardTimeframeComparisonTileOutputV1.
        :type: bool
        """
        if skipped is None:
            raise ValueError("Invalid value for `skipped`, must not be `None`")

        self._skipped = skipped

    @property
    def tile_id(self):
        """
        Gets the tile_id of this BoardTimeframeComparisonTileOutputV1.
        Tile id

        :return: The tile_id of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._tile_id

    @tile_id.setter
    def tile_id(self, tile_id):
        """
        Sets the tile_id of this BoardTimeframeComparisonTileOutputV1.
        Tile id

        :param tile_id: The tile_id of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """
        if tile_id is None:
            raise ValueError("Invalid value for `tile_id`, must not be `None`")

        self._tile_id = tile_id

    @property
    def tile_name(self):
        """
        Gets the tile_name of this BoardTimeframeComparisonTileOutputV1.
        Tile name

        :return: The tile_name of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._tile_name

    @tile_name.setter
    def tile_name(self, tile_name):
        """
        Sets the tile_name of this BoardTimeframeComparisonTileOutputV1.
        Tile name

        :param tile_name: The tile_name of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """
        if tile_name is None:
            raise ValueError("Invalid value for `tile_name`, must not be `None`")

        self._tile_name = tile_name

    @property
    def tile_type(self):
        """
        Gets the tile_type of this BoardTimeframeComparisonTileOutputV1.
        Tile type

        :return: The tile_type of this BoardTimeframeComparisonTileOutputV1.
        :rtype: str
        """
        return self._tile_type

    @tile_type.setter
    def tile_type(self, tile_type):
        """
        Sets the tile_type of this BoardTimeframeComparisonTileOutputV1.
        Tile type

        :param tile_type: The tile_type of this BoardTimeframeComparisonTileOutputV1.
        :type: str
        """
        if tile_type is None:
            raise ValueError("Invalid value for `tile_type`, must not be `None`")

        self._tile_type = tile_type

    @property
    def variations(self):
        """
        Gets the variations of this BoardTimeframeComparisonTileOutputV1.
        Variations found for this tile

        :return: The variations of this BoardTimeframeComparisonTileOutputV1.
        :rtype: list[BoardTimeframeComparisonMetricOutputV1]
        """
        return self._variations

    @variations.setter
    def variations(self, variations):
        """
        Sets the variations of this BoardTimeframeComparisonTileOutputV1.
        Variations found for this tile

        :param variations: The variations of this BoardTimeframeComparisonTileOutputV1.
        :type: list[BoardTimeframeComparisonMetricOutputV1]
        """
        if variations is None:
            raise ValueError("Invalid value for `variations`, must not be `None`")

        self._variations = variations

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTimeframeComparisonTileOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
