# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableComputeOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _compute_results: Dict[str, List[RowRulesResultV1]]
    _table_definition: TableDefinitionOutputV1


    def __init__(
        self,
        compute_results: Optional[Dict[str, List[RowRulesResultV1]]] = None,
        table_definition: Optional[TableDefinitionOutputV1] = None,
    ) -> None: ...

    @property
    def compute_results(self) -> Dict[str, List[RowRulesResultV1]]: ...

    @compute_results.setter
    def compute_results(self, compute_results: Dict[str, List[RowRulesResultV1]]) -> None: ...

    @property
    def table_definition(self) -> TableDefinitionOutputV1: ...

    @table_definition.setter
    def table_definition(self, table_definition: TableDefinitionOutputV1) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
