# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DerivedFeatureV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _id: Optional[str]
    _is_output: Optional[bool]
    _name: str
    _output_type: str
    _rules: List[FeatureRuleV1]


    def __init__(
        self,
        description: Optional[str] = None,
        id: Optional[str] = None,
        is_output: Optional[bool] = None,
        name: Optional[str] = None,
        output_type: Optional[str] = None,
        rules: Optional[List[FeatureRuleV1]] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def is_output(self) -> Optional[bool]: ...

    @is_output.setter
    def is_output(self, is_output: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def output_type(self) -> str: ...

    @output_type.setter
    def output_type(self, output_type: str) -> None: ...

    @property
    def rules(self) -> List[FeatureRuleV1]: ...

    @rules.setter
    def rules(self, rules: List[FeatureRuleV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
