# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaUpgradeOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _after_formula: Optional[str]
    _before_formula: Optional[str]
    _changes: Optional[List[FormulaUpgradeChangeV1]]
    _new_version: Optional[int]
    _old_version: Optional[int]


    def __init__(
        self,
        after_formula: Optional[str] = None,
        before_formula: Optional[str] = None,
        changes: Optional[List[FormulaUpgradeChangeV1]] = None,
        new_version: Optional[int] = None,
        old_version: Optional[int] = None,
    ) -> None: ...

    @property
    def after_formula(self) -> Optional[str]: ...

    @after_formula.setter
    def after_formula(self, after_formula: Optional[str]) -> None: ...

    @property
    def before_formula(self) -> Optional[str]: ...

    @before_formula.setter
    def before_formula(self, before_formula: Optional[str]) -> None: ...

    @property
    def changes(self) -> Optional[List[FormulaUpgradeChangeV1]]: ...

    @changes.setter
    def changes(self, changes: Optional[List[FormulaUpgradeChangeV1]]) -> None: ...

    @property
    def new_version(self) -> Optional[int]: ...

    @new_version.setter
    def new_version(self, new_version: Optional[int]) -> None: ...

    @property
    def old_version(self) -> Optional[int]: ...

    @old_version.setter
    def old_version(self, old_version: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
