# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class StoredTableSearchFailureOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message_key': 'str',
        'row_id': 'str',
        'search_string': 'str',
        'stored_table_id': 'str'
    }

    attribute_map = {
        'message_key': 'messageKey',
        'row_id': 'rowId',
        'search_string': 'searchString',
        'stored_table_id': 'storedTableId'
    }

    def __init__(self, message_key=None, row_id=None, search_string=None, stored_table_id=None):
        """
        StoredTableSearchFailureOutputV1 - a model defined in Swagger
        """

        self._message_key = None
        self._row_id = None
        self._search_string = None
        self._stored_table_id = None

        if message_key is not None:
          self.message_key = message_key
        if row_id is not None:
          self.row_id = row_id
        if search_string is not None:
          self.search_string = search_string
        if stored_table_id is not None:
          self.stored_table_id = stored_table_id

    @property
    def message_key(self):
        """
        Gets the message_key of this StoredTableSearchFailureOutputV1.
        Message key for translating the failure message

        :return: The message_key of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._message_key

    @message_key.setter
    def message_key(self, message_key):
        """
        Sets the message_key of this StoredTableSearchFailureOutputV1.
        Message key for translating the failure message

        :param message_key: The message_key of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if message_key is None:
            raise ValueError("Invalid value for `message_key`, must not be `None`")

        self._message_key = message_key

    @property
    def row_id(self):
        """
        Gets the row_id of this StoredTableSearchFailureOutputV1.
        Id of the row in the stored table associated with this failure

        :return: The row_id of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._row_id

    @row_id.setter
    def row_id(self, row_id):
        """
        Sets the row_id of this StoredTableSearchFailureOutputV1.
        Id of the row in the stored table associated with this failure

        :param row_id: The row_id of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if row_id is None:
            raise ValueError("Invalid value for `row_id`, must not be `None`")

        self._row_id = row_id

    @property
    def search_string(self):
        """
        Gets the search_string of this StoredTableSearchFailureOutputV1.
        Search string that failed for the row in the stored table associated with this failure

        :return: The search_string of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._search_string

    @search_string.setter
    def search_string(self, search_string):
        """
        Sets the search_string of this StoredTableSearchFailureOutputV1.
        Search string that failed for the row in the stored table associated with this failure

        :param search_string: The search_string of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if search_string is None:
            raise ValueError("Invalid value for `search_string`, must not be `None`")

        self._search_string = search_string

    @property
    def stored_table_id(self):
        """
        Gets the stored_table_id of this StoredTableSearchFailureOutputV1.
        Id of the stored table associated with this failure

        :return: The stored_table_id of this StoredTableSearchFailureOutputV1.
        :rtype: str
        """
        return self._stored_table_id

    @stored_table_id.setter
    def stored_table_id(self, stored_table_id):
        """
        Sets the stored_table_id of this StoredTableSearchFailureOutputV1.
        Id of the stored table associated with this failure

        :param stored_table_id: The stored_table_id of this StoredTableSearchFailureOutputV1.
        :type: str
        """
        if stored_table_id is None:
            raise ValueError("Invalid value for `stored_table_id`, must not be `None`")

        self._stored_table_id = stored_table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, StoredTableSearchFailureOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
