# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaDocOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _children: Optional[List[SeeAlsoDocOutputV1]]
    _constants: Optional[List[str]]
    _description: Optional[str]
    _doc_created_at: Optional[str]
    _doc_updated_at: Optional[str]
    _documentation_href: Optional[str]
    _examples: Optional[List[FormulaExampleOutputV1]]
    _excel_synonyms: Optional[List[str]]
    _function_group_id: Optional[str]
    _functions: Optional[List[FunctionVariantOutputV1]]
    _images: Optional[List[str]]
    _keywords: Optional[List[str]]
    _package_created_at: Optional[str]
    _package_creator_contact_info: Optional[str]
    _package_creator_name: Optional[str]
    _package_id: Optional[str]
    _package_installer_name: Optional[str]
    _package_updated_at: Optional[str]
    _package_version: Optional[str]
    _parameters: Optional[List[ParameterDocOutputV1]]
    _parents: Optional[List[SeeAlsoDocOutputV1]]
    _see_alsos: Optional[List[SeeAlsoDocOutputV1]]
    _title: Optional[str]


    def __init__(
        self,
        children: Optional[List[SeeAlsoDocOutputV1]] = None,
        constants: Optional[List[str]] = None,
        description: Optional[str] = None,
        doc_created_at: Optional[str] = None,
        doc_updated_at: Optional[str] = None,
        documentation_href: Optional[str] = None,
        examples: Optional[List[FormulaExampleOutputV1]] = None,
        excel_synonyms: Optional[List[str]] = None,
        function_group_id: Optional[str] = None,
        functions: Optional[List[FunctionVariantOutputV1]] = None,
        images: Optional[List[str]] = None,
        keywords: Optional[List[str]] = None,
        package_created_at: Optional[str] = None,
        package_creator_contact_info: Optional[str] = None,
        package_creator_name: Optional[str] = None,
        package_id: Optional[str] = None,
        package_installer_name: Optional[str] = None,
        package_updated_at: Optional[str] = None,
        package_version: Optional[str] = None,
        parameters: Optional[List[ParameterDocOutputV1]] = None,
        parents: Optional[List[SeeAlsoDocOutputV1]] = None,
        see_alsos: Optional[List[SeeAlsoDocOutputV1]] = None,
        title: Optional[str] = None,
    ) -> None: ...

    @property
    def children(self) -> Optional[List[SeeAlsoDocOutputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[SeeAlsoDocOutputV1]]) -> None: ...

    @property
    def constants(self) -> Optional[List[str]]: ...

    @constants.setter
    def constants(self, constants: Optional[List[str]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def doc_created_at(self) -> Optional[str]: ...

    @doc_created_at.setter
    def doc_created_at(self, doc_created_at: Optional[str]) -> None: ...

    @property
    def doc_updated_at(self) -> Optional[str]: ...

    @doc_updated_at.setter
    def doc_updated_at(self, doc_updated_at: Optional[str]) -> None: ...

    @property
    def documentation_href(self) -> Optional[str]: ...

    @documentation_href.setter
    def documentation_href(self, documentation_href: Optional[str]) -> None: ...

    @property
    def examples(self) -> Optional[List[FormulaExampleOutputV1]]: ...

    @examples.setter
    def examples(self, examples: Optional[List[FormulaExampleOutputV1]]) -> None: ...

    @property
    def excel_synonyms(self) -> Optional[List[str]]: ...

    @excel_synonyms.setter
    def excel_synonyms(self, excel_synonyms: Optional[List[str]]) -> None: ...

    @property
    def function_group_id(self) -> Optional[str]: ...

    @function_group_id.setter
    def function_group_id(self, function_group_id: Optional[str]) -> None: ...

    @property
    def functions(self) -> Optional[List[FunctionVariantOutputV1]]: ...

    @functions.setter
    def functions(self, functions: Optional[List[FunctionVariantOutputV1]]) -> None: ...

    @property
    def images(self) -> Optional[List[str]]: ...

    @images.setter
    def images(self, images: Optional[List[str]]) -> None: ...

    @property
    def keywords(self) -> Optional[List[str]]: ...

    @keywords.setter
    def keywords(self, keywords: Optional[List[str]]) -> None: ...

    @property
    def package_created_at(self) -> Optional[str]: ...

    @package_created_at.setter
    def package_created_at(self, package_created_at: Optional[str]) -> None: ...

    @property
    def package_creator_contact_info(self) -> Optional[str]: ...

    @package_creator_contact_info.setter
    def package_creator_contact_info(self, package_creator_contact_info: Optional[str]) -> None: ...

    @property
    def package_creator_name(self) -> Optional[str]: ...

    @package_creator_name.setter
    def package_creator_name(self, package_creator_name: Optional[str]) -> None: ...

    @property
    def package_id(self) -> Optional[str]: ...

    @package_id.setter
    def package_id(self, package_id: Optional[str]) -> None: ...

    @property
    def package_installer_name(self) -> Optional[str]: ...

    @package_installer_name.setter
    def package_installer_name(self, package_installer_name: Optional[str]) -> None: ...

    @property
    def package_updated_at(self) -> Optional[str]: ...

    @package_updated_at.setter
    def package_updated_at(self, package_updated_at: Optional[str]) -> None: ...

    @property
    def package_version(self) -> Optional[str]: ...

    @package_version.setter
    def package_version(self, package_version: Optional[str]) -> None: ...

    @property
    def parameters(self) -> Optional[List[ParameterDocOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[ParameterDocOutputV1]]) -> None: ...

    @property
    def parents(self) -> Optional[List[SeeAlsoDocOutputV1]]: ...

    @parents.setter
    def parents(self, parents: Optional[List[SeeAlsoDocOutputV1]]) -> None: ...

    @property
    def see_alsos(self) -> Optional[List[SeeAlsoDocOutputV1]]: ...

    @see_alsos.setter
    def see_alsos(self, see_alsos: Optional[List[SeeAlsoDocOutputV1]]) -> None: ...

    @property
    def title(self) -> Optional[str]: ...

    @title.setter
    def title(self, title: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
