# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UsageOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bytes: int
    _cache_type: Optional[str]
    _calls: int
    _content: int
    _context_writes: int
    _credits: float
    _identity: Optional[str]
    _identity_id: Optional[str]
    _impact_report_status: Optional[str]
    _impact_reports: int
    _prompts: int
    _source_label: Optional[str]
    _source_url: Optional[str]
    _timestamp: Optional[str]
    _tokens: int
    _type: Optional[str]
    _visits: int


    def __init__(
        self,
        bytes: Optional[int] = None,
        cache_type: Optional[str] = None,
        calls: Optional[int] = None,
        content: Optional[int] = None,
        context_writes: Optional[int] = None,
        credits: Optional[float] = None,
        identity: Optional[str] = None,
        identity_id: Optional[str] = None,
        impact_report_status: Optional[str] = None,
        impact_reports: Optional[int] = None,
        prompts: Optional[int] = None,
        source_label: Optional[str] = None,
        source_url: Optional[str] = None,
        timestamp: Optional[str] = None,
        tokens: Optional[int] = None,
        type: Optional[str] = None,
        visits: Optional[int] = None,
    ) -> None: ...

    @property
    def bytes(self) -> int: ...

    @bytes.setter
    def bytes(self, bytes: int) -> None: ...

    @property
    def cache_type(self) -> Optional[str]: ...

    @cache_type.setter
    def cache_type(self, cache_type: Optional[str]) -> None: ...

    @property
    def calls(self) -> int: ...

    @calls.setter
    def calls(self, calls: int) -> None: ...

    @property
    def content(self) -> int: ...

    @content.setter
    def content(self, content: int) -> None: ...

    @property
    def context_writes(self) -> int: ...

    @context_writes.setter
    def context_writes(self, context_writes: int) -> None: ...

    @property
    def credits(self) -> float: ...

    @credits.setter
    def credits(self, credits: float) -> None: ...

    @property
    def identity(self) -> Optional[str]: ...

    @identity.setter
    def identity(self, identity: Optional[str]) -> None: ...

    @property
    def identity_id(self) -> Optional[str]: ...

    @identity_id.setter
    def identity_id(self, identity_id: Optional[str]) -> None: ...

    @property
    def impact_report_status(self) -> Optional[str]: ...

    @impact_report_status.setter
    def impact_report_status(self, impact_report_status: Optional[str]) -> None: ...

    @property
    def impact_reports(self) -> int: ...

    @impact_reports.setter
    def impact_reports(self, impact_reports: int) -> None: ...

    @property
    def prompts(self) -> int: ...

    @prompts.setter
    def prompts(self, prompts: int) -> None: ...

    @property
    def source_label(self) -> Optional[str]: ...

    @source_label.setter
    def source_label(self, source_label: Optional[str]) -> None: ...

    @property
    def source_url(self) -> Optional[str]: ...

    @source_url.setter
    def source_url(self, source_url: Optional[str]) -> None: ...

    @property
    def timestamp(self) -> Optional[str]: ...

    @timestamp.setter
    def timestamp(self, timestamp: Optional[str]) -> None: ...

    @property
    def tokens(self) -> int: ...

    @tokens.setter
    def tokens(self, tokens: int) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def visits(self) -> int: ...

    @visits.setter
    def visits(self, visits: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
