# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonResultOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _baseline_range: str
    _board_id: str
    _board_name: str
    _current_range: str
    _tiles: List[BoardTimeframeComparisonTileOutputV1]
    _tiles_analyzed: int
    _tiles_skipped: int


    def __init__(
        self,
        baseline_range: Optional[str] = None,
        board_id: Optional[str] = None,
        board_name: Optional[str] = None,
        current_range: Optional[str] = None,
        tiles: Optional[List[BoardTimeframeComparisonTileOutputV1]] = None,
        tiles_analyzed: Optional[int] = None,
        tiles_skipped: Optional[int] = None,
    ) -> None: ...

    @property
    def baseline_range(self) -> str: ...

    @baseline_range.setter
    def baseline_range(self, baseline_range: str) -> None: ...

    @property
    def board_id(self) -> str: ...

    @board_id.setter
    def board_id(self, board_id: str) -> None: ...

    @property
    def board_name(self) -> str: ...

    @board_name.setter
    def board_name(self, board_name: str) -> None: ...

    @property
    def current_range(self) -> str: ...

    @current_range.setter
    def current_range(self, current_range: str) -> None: ...

    @property
    def tiles(self) -> List[BoardTimeframeComparisonTileOutputV1]: ...

    @tiles.setter
    def tiles(self, tiles: List[BoardTimeframeComparisonTileOutputV1]) -> None: ...

    @property
    def tiles_analyzed(self) -> int: ...

    @tiles_analyzed.setter
    def tiles_analyzed(self, tiles_analyzed: int) -> None: ...

    @property
    def tiles_skipped(self) -> int: ...

    @tiles_skipped.setter
    def tiles_skipped(self, tiles_skipped: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
