# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class JobOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _configuration: Optional[Dict[str, Any]]
    _currently_running: bool
    _document_id: Optional[str]
    _document_name: Optional[str]
    _duration: Optional[int]
    _group: str
    _id: str
    _next_run_time: Optional[str]
    _previous_run_time: Optional[str]
    _result: Optional[str]
    _status: Optional[str]
    _status_message: Optional[str]
    _topic_id: Optional[str]
    _topic_name: Optional[str]
    _user_id: Optional[str]


    def __init__(
        self,
        configuration: Optional[Dict[str, Any]] = None,
        currently_running: Optional[bool] = None,
        document_id: Optional[str] = None,
        document_name: Optional[str] = None,
        duration: Optional[int] = None,
        group: Optional[str] = None,
        id: Optional[str] = None,
        next_run_time: Optional[str] = None,
        previous_run_time: Optional[str] = None,
        result: Optional[str] = None,
        status: Optional[str] = None,
        status_message: Optional[str] = None,
        topic_id: Optional[str] = None,
        topic_name: Optional[str] = None,
        user_id: Optional[str] = None,
    ) -> None: ...

    @property
    def configuration(self) -> Optional[Dict[str, Any]]: ...

    @configuration.setter
    def configuration(self, configuration: Optional[Dict[str, Any]]) -> None: ...

    @property
    def currently_running(self) -> bool: ...

    @currently_running.setter
    def currently_running(self, currently_running: bool) -> None: ...

    @property
    def document_id(self) -> Optional[str]: ...

    @document_id.setter
    def document_id(self, document_id: Optional[str]) -> None: ...

    @property
    def document_name(self) -> Optional[str]: ...

    @document_name.setter
    def document_name(self, document_name: Optional[str]) -> None: ...

    @property
    def duration(self) -> Optional[int]: ...

    @duration.setter
    def duration(self, duration: Optional[int]) -> None: ...

    @property
    def group(self) -> str: ...

    @group.setter
    def group(self, group: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def previous_run_time(self) -> Optional[str]: ...

    @previous_run_time.setter
    def previous_run_time(self, previous_run_time: Optional[str]) -> None: ...

    @property
    def result(self) -> Optional[str]: ...

    @result.setter
    def result(self, result: Optional[str]) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def topic_id(self) -> Optional[str]: ...

    @topic_id.setter
    def topic_id(self, topic_id: Optional[str]) -> None: ...

    @property
    def topic_name(self) -> Optional[str]: ...

    @topic_name.setter
    def topic_name(self, topic_name: Optional[str]) -> None: ...

    @property
    def user_id(self) -> Optional[str]: ...

    @user_id.setter
    def user_id(self, user_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
