# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DirectItemIdsSourceV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_id: Optional[str]
    _condition_stats: Optional[List[ConditionTableStatInputForDirectItemsV1]]
    _item_ids: List[str]


    def __init__(
        self,
        asset_id: Optional[str] = None,
        condition_stats: Optional[List[ConditionTableStatInputForDirectItemsV1]] = None,
        item_ids: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def asset_id(self) -> Optional[str]: ...

    @asset_id.setter
    def asset_id(self, asset_id: Optional[str]) -> None: ...

    @property
    def condition_stats(self) -> Optional[List[ConditionTableStatInputForDirectItemsV1]]: ...

    @condition_stats.setter
    def condition_stats(self, condition_stats: Optional[List[ConditionTableStatInputForDirectItemsV1]]) -> None: ...

    @property
    def item_ids(self) -> List[str]: ...

    @item_ids.setter
    def item_ids(self, item_ids: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
