# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class FormulasApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def clear_cache(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def clear_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def compile_formula(
        self,
        **kwargs: Any,
    ) -> FormulaCompileOutputV1: ...

    def compile_formula_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def compile_formula_and_parameters(
        self,
        **kwargs: Any,
    ) -> FormulaCompileOutputV1: ...

    def compile_formula_and_parameters_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_function(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def create_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_item(
        self,
        **kwargs: Any,
    ) -> FormulaItemOutputV1: ...

    def create_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_formula_doc(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_formula_doc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_function(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_package(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def experimental(
        self,
        **kwargs: Any,
    ) -> FormulaGenericOutputV1: ...

    def experimental_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def formula_explainer(
        self,
        **kwargs: Any,
    ) -> FormulaGenericOutputV1: ...

    def formula_explainer_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def formula_explainer_markdown(
        self,
        **kwargs: Any,
    ) -> None: ...

    def formula_explainer_markdown_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_constant_name_list(
        self,
        **kwargs: Any,
    ) -> List[str]: ...

    def get_constant_name_list_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_doc(
        self,
        **kwargs: Any,
    ) -> FormulaDocOutputV1: ...

    def get_formula_doc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_docs(
        self,
        **kwargs: Any,
    ) -> FormulaDocSummariesOutputV1: ...

    def get_formula_docs_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_functions(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_formula_functions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_function(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def get_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item(
        self,
        **kwargs: Any,
    ) -> FormulaItemOutputV1: ...

    def get_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_package(
        self,
        **kwargs: Any,
    ) -> FormulaPackageOutputV1: ...

    def get_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_packages(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_packages_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def import_package(
        self,
        **kwargs: Any,
    ) -> FormulaPackageImportOutputV1: ...

    def import_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_formula_doc(
        self,
        **kwargs: Any,
    ) -> FormulaDocOutputV1: ...

    def put_formula_doc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_package(
        self,
        **kwargs: Any,
    ) -> FormulaPackageOutputV1: ...

    def put_package_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def run_formula(
        self,
        **kwargs: Any,
    ) -> FormulaRunOutputV1: ...

    def run_formula_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def run_formula_0(
        self,
        **kwargs: Any,
    ) -> FormulaRunOutputV1: ...

    def run_formula_0_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_function(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def update_function_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
