# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConfigurationOptionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _advanced: bool
    _allowed_values: Optional[str]
    _default_dependencies: Optional[List[str]]
    _default_description: Optional[str]
    _default_value: Any
    _description: str
    _modifiable: bool
    _note: Optional[str]
    _path: str
    _registration: Optional[str]
    _registration_description: Optional[str]
    _units: Optional[str]
    _value: Optional[Any]


    def __init__(
        self,
        advanced: Optional[bool] = False,
        allowed_values: Optional[str] = None,
        default_dependencies: Optional[List[str]] = None,
        default_description: Optional[str] = None,
        default_value: Optional[Any] = None,
        description: Optional[str] = None,
        modifiable: Optional[bool] = False,
        note: Optional[str] = None,
        path: Optional[str] = None,
        registration: Optional[str] = None,
        registration_description: Optional[str] = None,
        units: Optional[str] = None,
        value: Optional[Any] = None,
    ) -> None: ...

    @property
    def advanced(self) -> bool: ...

    @advanced.setter
    def advanced(self, advanced: bool) -> None: ...

    @property
    def allowed_values(self) -> Optional[str]: ...

    @allowed_values.setter
    def allowed_values(self, allowed_values: Optional[str]) -> None: ...

    @property
    def default_dependencies(self) -> Optional[List[str]]: ...

    @default_dependencies.setter
    def default_dependencies(self, default_dependencies: Optional[List[str]]) -> None: ...

    @property
    def default_description(self) -> Optional[str]: ...

    @default_description.setter
    def default_description(self, default_description: Optional[str]) -> None: ...

    @property
    def default_value(self) -> Any: ...

    @default_value.setter
    def default_value(self, default_value: Any) -> None: ...

    @property
    def description(self) -> str: ...

    @description.setter
    def description(self, description: str) -> None: ...

    @property
    def modifiable(self) -> bool: ...

    @modifiable.setter
    def modifiable(self, modifiable: bool) -> None: ...

    @property
    def note(self) -> Optional[str]: ...

    @note.setter
    def note(self, note: Optional[str]) -> None: ...

    @property
    def path(self) -> str: ...

    @path.setter
    def path(self, path: str) -> None: ...

    @property
    def registration(self) -> Optional[str]: ...

    @registration.setter
    def registration(self, registration: Optional[str]) -> None: ...

    @property
    def registration_description(self) -> Optional[str]: ...

    @registration_description.setter
    def registration_description(self, registration_description: Optional[str]) -> None: ...

    @property
    def units(self) -> Optional[str]: ...

    @units.setter
    def units(self, units: Optional[str]) -> None: ...

    @property
    def value(self) -> Optional[Any]: ...

    @value.setter
    def value(self, value: Optional[Any]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
